###########################################################################################################
#### Script: MSc thesis Forecasting Drought Impacts
#### Date: 2019-03
#### Auther: Melati van der Weert
#### Supervisors: Samuel Sutanto, Henny van Lanen, and Niko Wanders
#### Chair group: Hydrology and Quantitative Water Management Group
#### University: Wageningen University & Research, the Netherlands
#### Objective: In the present script the EDII inventory is translated into binary timeseries
#### Instructions: Go through the script step by step and execute the R-code (select code and Ctrl-R).
#### If required set the working folder, input folder, and output folder according to your specifications
###########################################################################################################


## set working directory
setwd("F:/Thesis/Scripts/Rstudio/1_Drought_Impact/Case_4/1_Binary_EDII/")

## install required packages
install.packages("readxl")
library("readxl")

## load excel file
NUTS_name_number=read.table ("F:/Thesis/Data/1_Drought_Impact/NUTS1_Germany.csv",sep = ",",header=TRUE)
my_data <- read_excel("F:/Thesis/Data/1_Drought_Impact/EDII_Raw_Data/Inventory.xlsx")

## load functions
source("R/1_Empty_Dataframe.R")
source("R/2_Binary_Timeserie_EDII.R")

## list of all the NUTS1 regions in Germany
NUTS_list = c("Baden-Wrttemberg","Bayern","Berlin","Brandenburg","Bremen", "Hamburg","Hessen","Mecklenburg-Vorpommern","Niedersachsen","Nordrhein-Westfalen","Rheinland-Pfalz","Saarland","Sachsen","Sachsen-Anhalt","Schleswig-Holstein","Thringen")

## make binary timeserie of drought occurance for all selected NUTS region
for (NUTS in NUTS_list){
  print(NUTS)
  ## create an empty dataframe
  Empty_Dataframe_output = Empty_Dataframe(start_date="1990/1/1", end_date="2017/12/1")
  ## Translate EDII reports into a binary timeserie of drought occurance
  Binary_Timeserie_EDII_output = Binary_Timeserie_EDII(Country="DE", Nuts1=NUTS, impact_timeserie=Empty_Dataframe_output,my_data=my_data)
  ## write csv file binary timeserie of drought occurance
  NUTS_number = NUTS_name_number$Number[which(NUTS_name_number$Name == NUTS)]
  write.csv(Binary_Timeserie_EDII_output,paste0('F:/Thesis/Data/1_Drought_Impact/Case_4/Binary_EDII/',NUTS_number, '.csv'))
}


