###########################################################################################################
#### Script: MSc thesis Forecasting Drought Impacts
#### Date: 2019-03
#### Auther: Melati van der Weert
#### Supervisors: Samuel Sutanto, Henny van Lanen, and Niko Wanders
#### Chair group: Hydrology and Quantitative Water Management Group
#### University: Wageningen University & Research, the Netherlands
#### Objective: Convert Netcdf of yearly meteorological or hydrological variable with daily timesteps to
#### monthly timesteps
#### Instructions: Go through the script step by step and execute the R-code (select code and Ctrl-R).
#### If required set the working folder, input folder, and output folder according to your specifications
###########################################################################################################


## set working directory
workdir <- "F:/Thesis/Scripts/Rstudio/2_Drought_Indicies/Historical/1_Formating_Years_NetCDF"
setwd(workdir)

## install and load required packages
library(ncdf4)

## load functions
source("R/1_Leap_Year.R")
source("R/2_End_of_Month.R")
source("R/3_Days_to_Months.R")
source("R/4_Array_to_Netcdf.R")

## set input and output folder by defining parameter
parameter = "pr"
parameter = "et"
parameter = "dis"

if (parameter == "pr"){
  input_folder = "F:/Thesis/Data/2_Drought_Indicies/Historical/Meteorological_Data/Raw_Data/PR"
  output_folder = "F:/Thesis/Data/2_Drought_Indicies/Historical/Meteorological_Data/PR/Years"
}
if (parameter == "et"){
  input_folder = "F:/Thesis/Data/2_Drought_Indicies/Historical/Meteorological_Data/Raw_Data/ET"
  output_folder = "F:/Thesis/Data/2_Drought_Indicies/Historical/Meteorological_Data/ET/Years"
}
if (parameter == "dis"){
  input_folder = "F:/Thesis/Data/2_Drought_Indicies/Historical/Meteorological_Data/Raw_Data/DIS"
  output_folder = "F:/Thesis/Data/2_Drought_Indicies/Historical/Meteorological_Data/DIS/Years"
}


## go trough all the Netcdf filles within the specified directory
for (i in 1990:2016){
  print(paste('Working on year:', i))
  
  ## open NETCDF
  ncfname <- paste(input_folder, '/', parameter,toString(i), ".nc", sep="")
  dname <- "tmp"  
  ncin <- nc_open(ncfname)
  tmp.array <- ncvar_get(ncin)
  
  ## convert year Netcdf with timesteps of days to monthly timesteps
  leapyear = Leap_Year(year=i) ## identify wich years are leap years and wich are not
  endingday_month = End_of_Month(leap_year=leapyear) ## identify at wich day number the month ends
  year_months = Days_to_Months(netcdf_array=tmp.array ,endingday_month=endingday_month) ## merge daily data to monthly data
  Array_to_Netcdf(year=i,input_data=year_months,ncpath=output_folder, dlname=parameter) ## convert monthly data from array extend to a netcdf file
  
  ## close NETCDF file
  nc_close(ncin)
  
  ## set working directory again
  workdir <- "F:/Thesis/Scripts/Rstudio/2_Drought_Indicies/Historical/1_Formating_Years_NetCDF"
  setwd(workdir)
  
  ## load functions again
  source("R/1_Leap_Year.R")
  source("R/2_End_of_Month.R")
  source("R/3_Days_to_Months.R")
  source("R/4_Array_to_Netcdf.R")
}





