###########################################################################################################
#### Script: MSc thesis Forecasting Drought Impacts
#### Date: 2019-03
#### Auther: Melati van der Weert
#### Supervisors: Samuel Sutanto, Henny van Lanen, and Niko Wanders
#### Chair group: Hydrology and Quantitative Water Management Group
#### University: Wageningen University & Research, the Netherlands
#### Objective: Calculate drought indicies from proxy of observed hydro-meteorological data for Germany
#### Instructions: Go through the script step by step and execute the R-code (select code and Ctrl-R).
#### If required set the working folder, input folder, and output folder according to your specifications
###########################################################################################################


### set working directory
workdir = "F:/Thesis/Scripts/Rstudio/2_Drought_Indicies/Historical/3_Drought_Indicies_Germany_Level"
setwd(workdir)

## load packages
library(raster)
library(ncdf4)
library(rgdal)
library(maptools)
library(SPEI)

## load functions
source("R/1_NUTS_Timeserie.R")
source("R/2_Calc_Drought_Indicies.R")

## load raster of meteo-hydrological variable
PR_raster = brick("F:/Thesis/Data/2_Drought_Indicies/Historical/Meteorological_Data/PR/Time_Period/pr-timeperiod.nc")
ET_raster= brick("F:/Thesis/Data/2_Drought_Indicies/Historical/Meteorological_Data/ET/Time_Period/et-timeperiod.nc")
DIS_raster= brick("F:/Thesis/Data/2_Drought_Indicies/Historical/Meteorological_Data/DIS/Time_Period/dis-timeperiod.nc")

## load shapefile of Germany
Germany = readOGR("F:/Thesis/GIS/Shapefile/Germany/Germany_Prj.shp")

## mask raster to German dimensions
PR_raster_crop = crop(PR_raster, Germany, filename="", snap='near')
ET_raster_crop = crop(ET_raster, Germany, filename="", snap='near')
DIS_raster_crop = crop(DIS_raster, Germany, filename="", snap='near')

PR_raster_mask = mask(PR_raster_crop, Germany)
ET_raster_mask = mask(ET_raster_crop, Germany)
DIS_raster_mask = mask(DIS_raster_crop, Germany)

## create a dataframe for timeseries of various variables for Germany and calculate average values of proxy of observed hydro-meteorological data
timeserie_Germany= NUTS_Timeserie(PR_raster_NUTS_mask=PR_raster_mask, ET_raster_NUTS_mask=ET_raster_mask, DIS_raster_NUTS_mask=DIS_raster_mask)
## calculate drought indicaies 
timeserie_Drought_Germany = Calc_Drought_Indicies(timeserie_NUTS=timeserie_Germany)

  



