###########################################################################################################
#### Script: MSc thesis Forecasting Drought Impacts
#### Date: 2019-03
#### Auther: Melati van der Weert
#### Supervisors: Samuel Sutanto, Henny van Lanen, and Niko Wanders
#### Chair group: Hydrology and Quantitative Water Management Group
#### University: Wageningen University & Research, the Netherlands
#### Objective: Required filles are copied and placed in a logical and workable sets of folders from an
#### external hardrive provided by the supervisors (only applicable for year 2008 from the harddrive)
#### Instructions: Go through the script step by step and execute the R-code (select code and Ctrl-R).
#### If required set the working folder, input folder, and output folder according to your specifications
###########################################################################################################


## define all the ensambles
ensambles = c("p00","p01","p02","p03","p04","p05","p06","p07","p08","p09","p10","p11","p12","p13","p14")

## define the dates and filles wich are going to be copied and extracted
dates = seq(as.Date(paste0("2008-09-01")), as.Date(paste0("2008-12-01")), "months")
dates = format(dates,format="%Y%m")

## get all filles/netcdf within the folder  
filles = list.files(path = paste0("G:/HINDCAST/2008/15ens-diffens"), pattern = NULL, all.files = FALSE,
                    full.names = TRUE, recursive = FALSE,
                    ignore.case = FALSE, include.dirs = FALSE, no.. = FALSE)

## index which pinpoints at wich file we are in the file list
index = 0

## go trough the dates folders
for (date in dates){
  
  ## go trought the ensamble folders
  for (ensamble in ensambles){
    
    ## define the file which is currently processed
    index=index+1
    file = filles[index]
    print(file)
    
    ## unpack the ziped file
    untar(file, exdir = "G:/Melati/Untar")
    
    ## get the required evapotranspiration, precipitation, and runoff folders and define the new ouput location
    E24a_Fille_In = paste0(list.files(path = "G:/Melati/Untar/" ,full.names = TRUE),"/E24a.nc")
    E24a_Fille_Out = paste("G:/Melati", '/E24a/', ensamble, '/', date, ".nc", sep="")
    R24a_Fille_In = paste0(list.files(path = "G:/Melati/Untar/" ,full.names = TRUE),"/R24a.nc")
    R24a_Fille_Out = paste("G:/Melati", '/R24a/', ensamble, '/', date, ".nc", sep="")
    dis_Fille_In = paste0(list.files(path = "G:/Melati/Untar/" ,full.names = TRUE),"/dis.nc")
    dis_Fille_Out = paste("G:/Melati", '/dis/', ensamble, '/', date, ".nc", sep="")
    
    ## copy and move the filles/netcdf
    file.copy(from = E24a_Fille_In, to = E24a_Fille_Out)
    file.copy(from = R24a_Fille_In, to = R24a_Fille_Out)
    file.copy(from = dis_Fille_In, to = dis_Fille_Out)
    
    ## delete the filles wich was unpacked
    unlink(list.files(path = "G:/Melati/Untar/" ,full.names = TRUE), recursive = TRUE)
  }
}










