###########################################################################################################
#### Script: MSc thesis Forecasting Drought Impacts
#### Date: 2019-03
#### Auther: Melati van der Weert
#### Supervisors: Samuel Sutanto, Henny van Lanen, and Niko Wanders
#### Chair group: Hydrology and Quantitative Water Management Group
#### University: Wageningen University & Research, the Netherlands
#### Objective: Convert Netcdf with daily timesteps to monthly timesteps
#### Instructions: Go through the script step by step and execute the R-code (select code and Ctrl-R).
#### If required set the working folder, input folder, and output folder according to your specifications
###########################################################################################################


## set working directory
workdir <- "F:/Thesis/Scripts/Rstudio/2_Drought_Indicies/Reforecast/2_Formating_Days_to_Month"
setwd(workdir)

# install required packages
install.packages("ncdf4")
install.packages("lubridate")

## Load required packages
library("lubridate")
library("ncdf4")

## load functions
source("R/1_Days_in_Month_List.R")
source("R/2_Forecast_Array.R")
source("R/3_Forecast_NetCDF.R")

## define the hydro-meteorological parameter set
dlname = "PR"
dlname = "ET"
dlname = "DIS"

## location ensamble folders
if (dlname == "ET"){
  ensamble_folder = "F:/Thesis/Data/2_Drought_Indicies/Reforecast/Meteorological_Data/Raw_Data/E24a"
}
if (dlname == "PR"){
  ensamble_folder = "F:/Thesis/Data/2_Drought_Indicies/Reforecast/Meteorological_Data/Raw_Data/R24a"
}
if (dlname == "DIS"){
  ensamble_folder = "F:/Thesis/Data/2_Drought_Indicies/Reforecast/Meteorological_Data/Raw_Data/dis"
}

## list of ensamble names
ensambles = c("p00","p01","p02","p03","p04","p05","p06","p07","p08","p09","p10","p11","p12","p13","p14")

## define the time range for which the data is available
date_start_period = "2002-01-01"
date_end_period = "2010-12-01"
period = seq(as.Date(date_start_period), as.Date(date_end_period), "months")

## output folder for the new formated forcasting data
output_folder = "F:/Thesis/Data/2_Drought_Indicies/Reforecast/Meteorological_Data"

## go trough every ensamble type
for (ensamble in ensambles){
  
  ## go trough all the filles
  for (i in seq_along(period)){
    
    ## print progress
    print(paste('Working on', ensamble, toString(format(period[i], "%Y%m")), sep=" "))
    
    ## open NETCDF of the specifeid file
    ncfname <-  paste(ensamble_folder,'/',toString(ensamble),'/',toString(format(period[i], "%Y%m")),'.nc',sep="")
    dname <- "tmp"  
    ncin <- nc_open(ncfname)
    timeperiod_array  <- ncvar_get(ncin)
    
    ## close NETCDF file
    nc_close(ncin)
    
    ## define the number of days within the forecasting months 
    lenght_days_month = Days_in_Month_List(forecasting_date = period[i])
    ## convert days to month forcasts
    input_data_NetCDF = Forecast_Array(timeperiod_array=timeperiod_array, lenght_days_month=lenght_days_month)
    ## write monthly forecast to new NetCDF
    Forecast_NetCDF(output_folder=output_folder, dlname=dlname, model=ensamble, date=format(period[i], "%Y%m"), input_data_NetCDF=input_data_NetCDF)
  }
}  
  



  


  
  

  
  