###########################################################################################################
#### Script: MSc thesis Forecasting Drought Impacts
#### Date: 2019-03
#### Auther: Melati van der Weert
#### Supervisors: Samuel Sutanto, Henny van Lanen, and Niko Wanders
#### Chair group: Hydrology and Quantitative Water Management Group
#### University: Wageningen University & Research, the Netherlands
#### Objective: Calculate drought indicies from reforecast data for NUTS-1 in Germany
#### Instructions: Go through the script step by step and execute the R-code (select code and Ctrl-R).
#### If required set the working folder, input folder, and output folder according to your specifications
###########################################################################################################


## set working directory
workdir <- "F:/Thesis/Scripts/Rstudio/2_Drought_Indicies/Reforecast/3_Drought_Indicies_NUTS1_Level"
setwd(workdir)

# install required packages
install.packages("ncdf4")
install.packages("lubridate")
install.packages("readr")

## Load required packages
library("lubridate")
library(ncdf4)
library(readr)
library(raster)
library(rgdal)
library(readr)

## load functions
source("R/1_NUTS_Timeserie_WB.R")
source("R/2_Calc_Drought_Indicies.R")

## list of ensamble names
ensambles = c("p00","p01","p02","p03","p04","p05","p06","p07","p08","p09","p10","p11","p12","p13","p14")

## bug SPEI package is now resolved
pze = 0

## go trough every ensamble type
for (ensamble in ensambles){
  
  # get all filles/netcdf within the year folder
  filles = list.files(path = paste0('F:/Thesis/Data/2_Drought_Indicies/Reforecast/Meteorological_Data/PR/',ensamble),  all.files = FALSE,
  full.names = FALSE, recursive = FALSE,
  ignore.case = FALSE, include.dirs = FALSE, no.. = FALSE,pattern= "*.nc$")
  
  ## go trough all the filles
  for (fille_name in filles){
    
    ## print progress
    print(paste('Working on', ensamble, paste0(gsub("(.{4})", "\\1-", gsub(pattern = "\\.nc$", "", fille_name)),"-01"), sep=" "))
    
    ## load raster
    PR_raster = brick( paste0('F:/Thesis/Data/2_Drought_Indicies/Reforecast/Meteorological_Data/PR/',ensamble,'/',fille_name))
    ET_raster = brick(paste0('F:/Thesis/Data/2_Drought_Indicies/Reforecast/Meteorological_Data/ET/',ensamble,'/',fille_name))
    DIS_raster = brick(paste0('F:/Thesis/Data/2_Drought_Indicies/Reforecast/Meteorological_Data/DIS/',ensamble,'/',fille_name))
    
    ## load shapefile
    NUTS = readOGR("F:/Thesis/GIS/Shapefile/NUTS/NUTS1_Germany_Prj.shp")
    NUTS_object = data.frame(NUTS$OBJECTID) 
    
    ## go trough every NUTS region
    for (j in NUTS_object$NUTS.OBJECTID){
      
      ## open proxy PR and ET timeseries for selected NUTS                                                                                                                      
      proxy = read_csv(paste0("F:/Thesis/Data/2_Drought_Indicies/Historical/Drought/Drought_Indicies/NUTS1_Level/",j,".csv"), 
                       col_types = cols(X1 = col_skip()))
 
      ## selcet NUTS region
      selected_NUTS <- NUTS[NUTS$OBJECTID == j,]
      
      ## mask raster to selected NUTS region dimensions
      PR_raster_NUTS_crop = crop(PR_raster, selected_NUTS, filename="", snap='near')
      ET_raster_NUTS_crop = crop(ET_raster, selected_NUTS, filename="", snap='near')
      DIS_raster_NUTS_crop = crop(DIS_raster, selected_NUTS, filename="", snap='near')
      
      PR_raster_NUTS_mask <- mask(PR_raster_NUTS_crop, selected_NUTS)
      ET_raster_NUTS_mask <- mask(ET_raster_NUTS_crop, selected_NUTS)
      DIS_raster_NUTS_mask <- mask(DIS_raster_NUTS_crop, selected_NUTS)
      
      ## create dataframe with average hydro-meteorological reforecast for selected NUTS region
      timeserie_NUTS = NUTS_Timeserie_WB(proxy=proxy, PR_raster_NUTS_mask=PR_raster_NUTS_mask, ET_raster_NUTS_mask=ET_raster_NUTS_mask, DIS_raster_NUTS_mask=DIS_raster_NUTS_mask, date=paste0(gsub("(.{4})", "\\1-", gsub(pattern = "\\.nc$", "", fille_name)),"-01"))
      
      ## create dataframe with drought indicies for selected NUTS region
      timeserie_Drought_NUTS = Calc_Drought_Indicies(timeserie_NUTS=timeserie_NUTS, NUTS_region = toString(j), model=ensamble,date=format(as.Date(paste0(gsub("(.{4})", "\\1-", gsub(pattern = "\\.nc$", "", fille_name)),"-01")), "%Y%m"))
      
      ## write csv file with hydro-meteorological reforecast data and drought indicies for NUTS-1 in Germany
      write.csv(timeserie_Drought_NUTS,paste0('F:/Thesis/Data/2_Drought_Indicies/Reforecast/Drought/Drought_Indicies/NUTS1_Level/', ensamble, '/',j, '/', gsub(pattern = "\\.nc$", "", fille_name),".csv"))
    }
  }    
}    
    
    
    
    
    
    


