###########################################################################################################
#### Script: MSc thesis Forecasting Drought Impacts
#### Date: 2019-03
#### Auther: Melati van der Weert
#### Supervisors: Samuel Sutanto, Henny van Lanen, and Niko Wanders
#### Chair group: Hydrology and Quantitative Water Management Group
#### University: Wageningen University & Research, the Netherlands
#### Objective: Create a model input to train random forest
#### Instructions: Go through the script step by step and execute the R-code (select code and Ctrl-R).
#### If required set the working folder, input folder, and output folder according to your specifications
###########################################################################################################

## Load required packages
library(readr)

## number and names of the NUTS1 regions in Germany
list_NUTS = c("741","743","750","753","775","776","777","791","796","800","810","835","843","858","903","979")

## go through the NUTS 1 regions
for (NUTS in list_NUTS){

  ## read EDII binary timeseries
  impacts = read_csv(paste0("F:/Thesis/Data/1_Drought_Impact/Case_4/Binary_EDII/",NUTS,".csv"),
           col_types = cols(X1 = col_skip()))
  
  ## read drought indices data
  drought_indicies = read_csv(paste0("F:/Thesis/Data/2_Drought_Indicies/Historical/Drought/Drought_Indicies/NUTS1_Level/",NUTS,".csv"),
                              col_types = cols(X1 = col_skip()))
  
  ## go through the combined impact categories
  for (category in 1:4){
    
    ## create dataframe for input model
    input_model = data.frame ("test"=0,"Year" = impacts$Year,"Month" = impacts$Month,
                         "Impact" = eval(parse(text = paste0("impacts$Impact_Combined_",category))),"SPI_1" = drought_indicies$SPI.1,
                         "SPI_3" = drought_indicies$SPI.3,"SPI_6" = drought_indicies$SPI.6,
                         "SPI_12" = drought_indicies$SPI.1,"SPEI_1" = drought_indicies$SPEI.1,
                         "SPEI_3" = drought_indicies$SPEI.3,"SPEI_6" = drought_indicies$SPEI.6,
                         "SPEI_12" = drought_indicies$SPEI.12,"SRI_1" = drought_indicies$SPEI.1,
                         "SRI_3" = drought_indicies$SPEI.3,"SRI_6" = drought_indicies$SPEI.6,
                         "SRI_12" = drought_indicies$SPEI.12)

    ## remove data for 1990 as some drought indices contain NA values
    input_model= input_model[13:336,]
    
    ## write csv file with LISFLOOD data and drought indicies for selected NUTS region
    write.csv(input_model,paste0('F:/Thesis/Data/3_Random_Forest/Historical_Analysis/Case_4/Model_Input/Binary/',NUTS,'/Impact_Combined_',category,'.csv'))
  }
}

   
  
  