###########################################################################################################
#### Script: MSc thesis Forecasting Drought Impacts
#### Date: 2019-03
#### Auther: Melati van der Weert
#### Supervisors: Samuel Sutanto, Henny van Lanen, and Niko Wanders
#### Chair group: Hydrology and Quantitative Water Management Group
#### University: Wageningen University & Research, the Netherlands
#### Objective: Define and rank the importance of each predictor variable in the drought impact functions
#### Instructions: Go through the script step by step and execute the R-code (select code and Ctrl-R).
#### If required set the working folder, input folder, and output folder according to your specifications
###########################################################################################################


## set working directory
workdir <- "F:/Thesis/Scripts/Rstudio/3_Random_Forest/Re-forecasts_Analysis/Case_4/3_Rank_Predictor_Importance"
setwd(workdir)

## Load required packages
library(readr)
library(randomForest)
library(lattice)
library(ggplot2)
library(RColorBrewer)
library(grid)
library(gridExtra)
library(caret)
library(dplyr)
library("ggExtra")
library(grid)
library(gtable)
library("caret")
require(lattice)

## load functions
source("R/1_Plot_Rank.R")

## list of predictors 
predictors <- c("SPI_1","SPI_3","SPI_6","SPI_12","SPEI_1","SPEI_3","SPEI_6","SPEI_12","SRI_1","SRI_3","SRI_6","SRI_12","Month","Year")
## list of indicies
indicies <- c("SPI-x","SPI-x","SPI-x","SPI-x","SPEI-x","SPEI-x","SPEI-x","SPEI-x","SRI-x","SRI-x","SRI-x","SRI-x"," "," ")
## list of NUTS regions numbers
list_NUTS <- c("741","743","750","753","775","776","777","791","796","800","810","835","843","858","903","979")
## list of NUTS regions names
list_NUTS1 = c("SL","BW","BV","RP","TH","HE","SX","NW","BE","ST","HB","BB","HH","LS","MP","SH")


## go trough the diffrent combined categories
for(category in 1:4){
  df = data.frame ("Indicies" = character(),"Predictor" = character(),"NUTS" = character(),"Rank" = integer())
  ## go trough every NUTS region
  for (NUTS in 1:length(list_NUTS)){ 
    
    ## open RF model if it exsits
    if(isTRUE(class(try(readRDS(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Model/",list_NUTS[NUTS],"/Impact_Combined_",category,".rds")),TRUE))=="try-error")){
      for (rank in 1:length(predictors)){
        newRow <- data.frame("Indicies" = indicies[rank],"Predictor" = predictors[rank],"NUTS" = list_NUTS1[NUTS],"Rank" = NA)
        df=rbind(df,newRow)
      }
    } else{
      model <- readRDS(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Model/",list_NUTS[NUTS],"/Impact_Combined_",category,".rds"))
      
      ## make empty array for results of ranked predictors
      result_rank = array(NA, dim = c(14)) 
      rownames(result_rank) <- c("SPI_1","SPI_3","SPI_6","SPI_12","SPEI_1","SPEI_3","SPEI_6","SPEI_12","SRI_1","SRI_3","SRI_6","SRI_12","Month","Year")
      
      
      ## rank de predictore importance
      for (predictor in 1:length(row.names(varImp(model)))){
        result_rank[row.names(varImp(model))[predictor]]= rank(varImp(model))[[predictor]]/length(rank(varImp(model))) 
      }
      
      newRow <- data.frame("Indicies" = indicies,"Predictor" = predictors,"NUTS" = array(list_NUTS1[NUTS], dim = c(14)),"Rank" = result_rank)
      df=rbind(df,newRow)
    }
  }
  
  ## save image
  jpeg(paste0("F:/Thesis/Figures/3_Random_Forest/Re-forecasts_Analysis/Case_4/Rank_Predictor_Importance/Combined_Impact_", category, ".jpg"))
  
  ## plot rank image
  plot(Plot_Rank(data_rank=df))
  
  ## close device
  dev.off()
}

