###########################################################################################################
#### Script: MSc thesis Forecasting Drought Impacts
#### Date: 2019-03
#### Auther: Melati van der Weert
#### Supervisors: Samuel Sutanto, Henny van Lanen, and Niko Wanders
#### Chair group: Hydrology and Quantitative Water Management Group
#### University: Wageningen University & Research, the Netherlands
#### Objective: Forecasting drought impact occurance
#### Instructions: Go through the script step by step and execute the R-code (select code and Ctrl-R).
#### If required set the working folder, input folder, and output folder according to your specifications
###########################################################################################################


## Load required packages
library(readr)
library(randomForest)

## number and names of the NUTS1 regions in Germany
list_NUTS = c("741","743","750","753","775","776","777","791","796","800","810","835","843","858","903","979")

## list of ensambles names
list_ensemble = c("p00","p01","p02","p03","p04","p05","p06","p07","p08","p09","p10","p11","p12","p13","p14")

## list of dates
list_dates = format(seq(as.Date("2002-01-01"), as.Date("2010-12-01"), "month"), "%Y%m")

## go through every NUTS 1 region
for (NUTS in list_NUTS){ print(NUTS)
  
  ## go through every combine impact category
  for (category in 1:4){ print(category)
    
    ## if there is no model don't do anything
    if(isTRUE(class(try(readRDS(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Model/",NUTS,"/Impact_Combined_",category,".rds")),TRUE))=="try-error")){
      
    } else{
      
      ## read the model
      model = readRDS(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Model/",NUTS,"/Impact_Combined_",category,".rds"))
      
      ## go through ensamble members
      for (ensemble in list_ensemble){ print(ensemble)
        
        ## go through date (forecasts)
        for(date in list_dates){
          
          ## create empty dataframe for forecasting results
          forecast_impact = array(-999,dim=c(7))
          
          ## load model input
          model_input = read_csv(paste0("F:/Thesis/Data/2_Drought_Indicies/Reforecast/Drought/Drought_Indicies/NUTS1_Level/",ensemble,"/",NUTS,"/",date,".csv"),
                                 col_types = cols(X1 = col_skip()))
          
          ## name variables model input
          names(model_input) = c("Year","Month","PR","ET","DIS","SPI_1","SPI_3","SPI_6","SPI_12","SPEI_1","SPEI_3","SPEI_6","SPEI_12","SRI_1","SRI_3","SRI_6","SRI_12")
          
          ## change month variable to integer
          model_input$Month = as.integer(model_input$Month)
          
          ## go through lead times
          for (LT in 1:7){
            
            ### RF is not possible get NA output
            if(isTRUE(class(try(predict(model,newdata = model_input[LT,] ,type="response"),TRUE))=="try-error")){
              
              forecast_impact[LT] = NA
              
              ## forecast impact occrurance probability
            } else{
              forecast_impact[LT] = predict(model,newdata = model_input[LT,],type="prob")[2]
            }
          }
          ## write predicted drought impact for the whole period in a CSV file
          write.csv(forecast_impact,paste0('F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Modelled_Drought_Impact/',ensemble,"/",NUTS,"/Impact_Combined_",category, "/",date,".csv"))
        }
      }
    }
  }
}
















