###########################################################################################################
#### Script: MSc thesis Forecasting Drought Impacts
#### Date: 2019-03
#### Auther: Melati van der Weert
#### Supervisors: Samuel Sutanto, Henny van Lanen, and Niko Wanders
#### Chair group: Hydrology and Quantitative Water Management Group
#### University: Wageningen University & Research, the Netherlands
#### Objective: Illustrating forecasted drought impact occurance
#### Instructions: Go through the script step by step and execute the R-code (select code and Ctrl-R).
#### If required set the working folder, input folder, and output folder according to your specifications
###########################################################################################################


## set working directory
workdir <- "F:/Thesis/Scripts/Rstudio/3_Random_Forest/Re-forecasts_Analysis/Case_4/4_Drought_Impact_Forecast"
setwd(workdir)

## Load required packages
install.packages('ggplot2')
library(ggplot2)
install.packages('grid')
library(grid)
install.packages('gridExtra')
library(gridExtra)
library(RColorBrewer)

## names of the NUTS1 regions in Germany
list_NUTS = c("835")
## list of ensambles names
list_ensemble = c("p00","p01","p02","p03","p04","p05","p06","p07","p08","p09","p10","p11","p12","p13","p14")
## list of impact categories
list_category = c("Impact_Combined_3")
## list of dates for wich forecast have been made
list_dates = format(seq(as.Date("2002-01-01"), as.Date("2010-12-01"), "month"), "%Y%m")

#### calculate BSS and ROC
## go trought every NUTS 1 level
for (NUTS in 1:length(list_NUTS)){ print(NUTS)
  ## go trought every impact category
  for (category in 1:length(list_category)){ 
    ## load proxy data wich incloud the proxy drought impact
    proxy = read.table(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Model_Input/Binary/",list_NUTS[NUTS],"/",list_category[category],".csv"),sep = ",",header=TRUE)
    ## create empty array needed to store data
    tmp.array = array(NA, dim = c(108,7,15))
    ## go trought every ensamble
    for (ensemble in 1:length(list_ensemble)){
      ## go trought every date
      for(date in 1:length(list_dates)){
        ## check if there is about for this perticalur situation -> if not there was no model built for this situation as the number of ipact reports were limited
        if(isTRUE(class(try(read.table(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Modelled_Drought_Impact/",list_ensemble[ensemble],"/",list_NUTS[NUTS],"/",list_category[category],"/",list_dates[date],".csv"),header = TRUE,sep = ","),TRUE))=="try-error")){
          tmp.array[date,,ensemble] = NA
        } else{
          ## load forecast
          forecast = read.table(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Modelled_Drought_Impact/",list_ensemble[ensemble],"/",list_NUTS[NUTS],"/",list_category[category],"/",list_dates[date],".csv"),header = TRUE,sep = ",")
          ## copy to empty array where all forecast for the perticalur NUTS region is merged into
          tmp.array[date,,ensemble] = forecast$x
        }
      }
    }

    ## average the ensemble values
    median=apply(tmp.array, c(1,2), median,na.rm=TRUE)
    lwr=apply(tmp.array, c(1,2), min,na.rm=TRUE)
    upr=apply(tmp.array, c(1,2), max,na.rm=TRUE)
    
    df = data.frame ("begin_date"=character() , "LT"=character(),"NUTS"=character(),"Impact"=character(), "date" = character() ,"median" = integer(),"lwr" = integer(),"upr" = integer(),"EDII" = integer())
    
    shade = data.frame('x1'= character(), 'x2'= character(), 'y1'= integer(), 'y2'= integer())
    
    ## go trough every lead time of the forecast
    for(forc in 1:108){
      ## define proxy and forecasted impact for every lead time for the whole case
      impact_proxy = proxy$Impact[(133-1+forc):(133+5+forc)]
      median_modelled = median[forc,]
      lwr_modelled = lwr[forc,]
      upr_modelled = upr[forc,]
      
      ## state the begin and end date
      begin_date = as.Date(paste0(proxy$Year[133-1+forc],"-",proxy$Month[133-1+forc],"-01"))
      end_date = as.Date(paste0(proxy$Year[133+5+forc],"-",proxy$Month[133+5+forc],"-01"))
      
      if(is.na(sum(median_modelled))){
      }else{
        
        ## create empty dataframe needed to plot in ggplot
        df1 = data.frame ("begin_date"=array(as.character(begin_date),c(7)),"LT"=as.character(c(1,2,3,4,5,6,7)),"NUTS"=array(list_NUTS[NUTS],c(7)),
                          "Impact"=array(list_category[category],c(7)), 
                          "date" = seq(begin_date, end_date, "months") ,"median" = median_modelled,"lwr" = lwr_modelled,"upr" = upr_modelled,"EDII" = impact_proxy)
        df=rbind(df,df1)
        
        ## function: defines date of date x months forward
        add_months= function(date,n) seq(date, by = paste (n, "months"), length = 2)[2]
        
        ## go trough the proxy of observed drought impact occurance
        for (i in 1:length(impact_proxy)){
          if (impact_proxy[i]==1){
            ## define start and end date of the particular forecast
            start=add_months(begin_date,(i-1))
            end=add_months(begin_date,(i))
            
            ## define new row 
            newRow <- data.frame("x1" = as.Date(start),"x2"=as.Date(end),"y1"=0,"y2"=1)
            ## merge dataframe withe new row
            shade=rbind(shade,newRow)
          }
        }
      }
    }
  }
}


## define colour scheme
colours=rainbow(7,alpha=0.8)

## create image showing an example of drought impact forecasting
Main= ggplot(df, aes(date, median, group=begin_date)) +
  facet_grid(. ~ "A. NUTS-1 BB Water Quality + \nFreshwater Ecosystem + Terrestrial Ecosystem")+ 
  scale_y_continuous(expand = c(0, 0))+
  scale_x_date(expand = c(0, 0))+
  geom_rect(data=shade,mapping=aes(xmin=as.Date(x1), xmax=as.Date(x2), ymin=y1, ymax=y2),fill='gray65',color = NA,inherit.aes = F)+
  annotate("rect", xmin=as.Date("2005-9-01"),ymin=0.0008,xmax=as.Date("2006-05-01"),ymax=0.2, alpha=0.5, fill="gray",color="red",size=1) +
  annotate("rect", xmin=as.Date("2002-11-01"),ymin=0.0008,xmax=as.Date("2003-07-01"),ymax=0.2, alpha=0.5, fill="gray",color="red",size=1) +
  geom_line(color='dodgerblue4')+
  ylab('Likelihood of Occurance (LIO)')+
  theme_bw()+
    theme(axis.title.x = element_blank(),
        plot.title = element_text(size = 9))+
  coord_cartesian(ylim=c(0,0.75))

## create image showing in wich the above image is zoomed in (at the beginning of the 2003 drought)
DR_2003 = ggplot(df, aes(date, median, group=begin_date)) +
  facet_grid(. ~ "B. Drought 2003")+ 
  scale_y_continuous(expand = c(0, 0))+
  scale_x_date(expand = c(0, 0), date_labels =  "%m")+
  geom_rect(data=shade,mapping=aes(xmin=as.Date(x1), xmax=as.Date(x2), ymin=y1, ymax=y2),inherit.aes = F,fill='gray65',color = NA)+
  geom_line(color='darkgreen',alpha=0)+
  geom_line(data=subset(df, begin_date == "2002-11-01"), colour=colours[1],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2002-12-01"), colour=colours[2],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2003-01-01"), colour=colours[3],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2003-02-01"), colour=colours[4],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2003-03-01"), colour=colours[5],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2003-04-01"), colour=colours[6],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2003-05-01"), colour=colours[7],linetype = "dashed")+
  geom_point(data=subset(df, begin_date == "2002-11-01"), colour=colours[1], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2002-12-01"), colour=colours[2], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2003-01-01"), colour=colours[3], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2003-02-01"), colour=colours[4], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2003-03-01"), colour=colours[5], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2003-04-01"), colour=colours[6], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2003-05-01"), colour=colours[7], size=2,shape=15)+
  theme_bw()+
  theme(
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    plot.title = element_blank())+
  coord_cartesian(xlim=c(as.Date("2002-11-01"),as.Date("2003-07-01")),ylim=c(0,0.25))+
  scale_color_manual(values = c(LT1 = "red", LT2 = "green", LT3 = "gray65"))


## create image showing in wich the above image is zoomed in (at the beginning of the 2006 drought)
DR_2006 = ggplot(df, aes(date, median, group=begin_date)) +
  facet_grid(. ~ "C. Drought 2006")+ 
  scale_y_continuous(expand = c(0, 0))+
  scale_x_date(expand = c(0, 0), date_labels =  "%m")+
  geom_rect(data=shade,mapping=aes(xmin=as.Date(x1), xmax=as.Date(x2), ymin=y1, ymax=y2),inherit.aes = F,fill='gray65',color = NA)+
  #geom_line(color='darkgreen',alpha=0)+
  geom_line(data=subset(df, begin_date == "2005-09-01"),colour=colours[1],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2005-10-01"), colour=colours[2],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2005-11-01"), colour=colours[3],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2005-12-01"), colour=colours[4],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2006-01-01"), colour=colours[5],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2006-02-01"), colour=colours[6],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2006-03-01"), colour=colours[7],linetype = "dashed")+
  geom_point(data=subset(df, begin_date == "2005-09-01"),color=colours[1], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2005-10-01"),color=colours[2], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2005-11-01"),color=colours[3], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2005-12-01"),color=colours[4], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2006-01-01"),color=colours[5], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2006-02-01"),color=colours[6], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2006-03-01"),color=colours[7], size=2,shape=15)+
  theme_bw()+
  theme(
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    plot.title = element_blank())+
  coord_cartesian(xlim=c(as.Date("2005-09-01"),as.Date("2006-05-01")),ylim=c(0,0.25))





df1=df[1:49,]


## create legend
legend_plot = ggplot(df1, aes(date, median ,colour=begin_date,group=begin_date)) +
  geom_rect(mapping=aes(xmin=as.Date("2002-11-01"), xmax=as.Date("2002-12-01"), ymin=0, ymax=1,fill="Observed"),inherit.aes = F)+
  geom_line(data=subset(df, begin_date == "2002-11-01"), aes(y=median,x=date,colour='dodgerblue4'))+
  geom_line(aes(date, median ,colour=begin_date,group=begin_date),linetype = "dashed")+
  geom_point(aes(date, median ,colour=begin_date,group=begin_date),shape=15)+
  theme_void()+
  theme(    #legend.box.background = element_rect(color="red", size=2),
            legend.box.margin = margin(5, 5, 18, 20),
    legend.justification = "bottom",
    legend.title=element_blank())+
  scale_fill_manual(values = alpha(c("gray65"), 1))+
  scale_color_manual(values=c("#FF0000CC","#FFDB00CC","#49FF00CC","#00FF92CC","#0092FFCC","#4900FFCC","#FF00DBCC",'dodgerblue4'),
                     labels = c("LT=7", "LT=6","LT=5","LT=4","LT=3","LT=2","LT=1","Forecasts"),
                     guide = guide_legend(override.aes = list(
                       linetype = c(rep("blank", 7),"solid"),
                       shape = c(rep(15, 7),NA))))
  
g_legend <- function(a.gplot){ 
  tmp <- ggplot_gtable(ggplot_build(a.gplot)) 
  leg <- which(sapply(tmp$grobs, function(x) x$name) == "guide-box") 
  legend <- tmp$grobs[[leg]] 
  return(legend)} 

legend_plot=g_legend(legend_plot)

plot(legend_plot)
########################################################################################################

## names of the NUTS1 regions in Germany
list_NUTS = c("903")
## list of ensambles names
list_ensemble = c("p00","p01","p02","p03","p04","p05","p06","p07","p08","p09","p10","p11","p12","p13","p14")
## list of impact categories
list_category = c("Impact_Combined_2")
## list of dates for wich forecast have been made
list_dates = format(seq(as.Date("2002-01-01"), as.Date("2010-12-01"), "month"), "%Y%m")

#### calculate BSS and ROC
## go trought every NUTS 1 level
for (NUTS in 1:length(list_NUTS)){ print(NUTS)
  ## go trought every impact category
  for (category in 1:length(list_category)){ 
    ## load proxy data wich incloud the proxy drought impact
    proxy = read.table(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Model_Input/Binary/",list_NUTS[NUTS],"/",list_category[category],".csv"),sep = ",",header=TRUE)
    ## create empty array needed to store data
    tmp.array = array(NA, dim = c(108,7,15))
    ## go trought every ensamble
    for (ensemble in 1:length(list_ensemble)){
      ## go trought every date
      for(date in 1:length(list_dates)){
        ## check if there is about for this perticalur situation -> if not there was no model built for this situation as the number of ipact reports were limited
        if(isTRUE(class(try(read.table(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Modelled_Drought_Impact/",list_ensemble[ensemble],"/",list_NUTS[NUTS],"/",list_category[category],"/",list_dates[date],".csv"),header = TRUE,sep = ","),TRUE))=="try-error")){
          tmp.array[date,,ensemble] = NA
        } else{
          ## load forecast
          forecast = read.table(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Modelled_Drought_Impact/",list_ensemble[ensemble],"/",list_NUTS[NUTS],"/",list_category[category],"/",list_dates[date],".csv"),header = TRUE,sep = ",")
          ## copy to empty array where all forecast for the perticalur NUTS region is merged into
          tmp.array[date,,ensemble] = forecast$x
        }
      }
    }
    
    ## average the ensemble values
    median=apply(tmp.array, c(1,2), median,na.rm=TRUE)
    lwr=apply(tmp.array, c(1,2), min,na.rm=TRUE)
    upr=apply(tmp.array, c(1,2), max,na.rm=TRUE)
    
    df = data.frame ("begin_date"=character() , "LT"=character(),"NUTS"=character(),"Impact"=character(), "date" = character() ,"median" = integer(),"lwr" = integer(),"upr" = integer(),"EDII" = integer())
    
    shade = data.frame('x1'= character(), 'x2'= character(), 'y1'= integer(), 'y2'= integer())
    
    ## go trough every lead time of the forecast
    for(forc in 1:108){
      ## define proxy and forecasted impact for every lead time for the whole case
      impact_proxy = proxy$Impact[(133-1+forc):(133+5+forc)]
      median_modelled = median[forc,]
      lwr_modelled = lwr[forc,]
      upr_modelled = upr[forc,]
      
      ## state the begin and end date
      begin_date = as.Date(paste0(proxy$Year[133-1+forc],"-",proxy$Month[133-1+forc],"-01"))
      end_date = as.Date(paste0(proxy$Year[133+5+forc],"-",proxy$Month[133+5+forc],"-01"))
      
      if(is.na(sum(median_modelled))){
      }else{
        
        ## create empty dataframe needed to plot in ggplot
        df1 = data.frame ("begin_date"=array(as.character(begin_date),c(7)),"LT"=as.character(c(1,2,3,4,5,6,7)),"NUTS"=array(list_NUTS[NUTS],c(7)),
                          "Impact"=array(list_category[category],c(7)), 
                          "date" = seq(begin_date, end_date, "months") ,"median" = median_modelled,"lwr" = lwr_modelled,"upr" = upr_modelled,"EDII" = impact_proxy)
        df=rbind(df,df1)
        
        ## function: defines date of date x months forward
        add_months= function(date,n) seq(date, by = paste (n, "months"), length = 2)[2]
        
        ## go trough the proxy of observed drought impact occurance
        for (i in 1:length(impact_proxy)){
          if (impact_proxy[i]==1){
            ## define start and end date of the particular forecast
            start=add_months(begin_date,(i-1))
            end=add_months(begin_date,(i))
            
            ## define new row 
            newRow <- data.frame("x1" = as.Date(start),"x2"=as.Date(end),"y1"=0,"y2"=1)
            ## merge dataframe withe new row
            shade=rbind(shade,newRow)
          }
        }
      }
    }
  }
}


## define colour scheme
colours=rainbow(7,alpha=0.8)

## create image showing an example of drought impact forecasting
Main2= ggplot(df, aes(date, median, group=begin_date)) +
  facet_grid(. ~ "D. NUTS-1 MP Water Quality + \nFreshwater Ecosystem + Terrestrial Ecosystem")+ 
  scale_y_continuous(expand = c(0, 0))+
  scale_x_date(expand = c(0, 0))+
  geom_rect(data=shade,mapping=aes(xmin=as.Date(x1), xmax=as.Date(x2), ymin=y1, ymax=y2),fill='gray65',color = NA,inherit.aes = F)+
  annotate("rect", xmin=as.Date("2002-12-01"),ymin=0.0008,xmax=as.Date("2003-08-01"),ymax=0.2, alpha=0.5, fill="gray",color="red",size=1) +
  annotate("rect", xmin=as.Date("2003-09-01"),ymin=0.0008,xmax=as.Date("2004-05-01"),ymax=0.65, alpha=0.5, fill="gray",color="red",size=1) +
  geom_line(color='dodgerblue4')+
  ylab('Likelihood of Occurance (LIO)')+
  theme_bw()+
  theme(axis.title.x = element_blank(),
        plot.title = element_text(size = 9))+
  coord_cartesian(ylim=c(0,0.75)) 

## create image showing in wich the above image is zoomed in (at the beginning of the 2003 drought)
DR_2003_B = ggplot(df, aes(date, median, group=begin_date)) +
  facet_grid(. ~ "E. Start Drought 2003")+ 
  scale_y_continuous(expand = c(0, 0))+
  scale_x_date(expand = c(0, 0), date_labels =  "%m")+
  geom_rect(data=shade,mapping=aes(xmin=as.Date(x1), xmax=as.Date(x2), ymin=y1, ymax=y2),inherit.aes = F,fill='gray65',color = NA)+
  geom_line(color='darkgreen',alpha=0)+
  geom_line(data=subset(df, begin_date == "2002-12-01"), colour=colours[1],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2003-01-01"), colour=colours[2],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2003-02-01"), colour=colours[3],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2003-03-01"), colour=colours[4],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2003-04-01"), colour=colours[5],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2003-05-01"), colour=colours[6],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2003-06-01"), colour=colours[7],linetype = "dashed")+
  geom_point(data=subset(df, begin_date == "2002-12-01"), colour=colours[1], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2003-01-01"), colour=colours[2], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2003-02-01"), colour=colours[3], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2003-03-01"), colour=colours[4], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2003-04-01"), colour=colours[5], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2003-05-01"), colour=colours[6], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2003-06-01"), colour=colours[7], size=2,shape=15)+
  theme_bw()+
  theme(
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    plot.title = element_blank())+
  coord_cartesian(xlim=c(as.Date("2002-12-01"),as.Date("2003-08-01")),ylim=c(0,0.25))+
  scale_color_manual(values = c(LT1 = "red", LT2 = "green", LT3 = "gray65"))

## create image showing in wich the above image is zoomed in (at the end of the 2003 drought)
DR_2003_E = ggplot(df, aes(date, median, group=begin_date)) +
  facet_grid(. ~ "F. End Drought 2003")+ 
  scale_y_continuous(expand = c(0, 0))+
  scale_x_date(expand = c(0, 0), date_labels =  "%m")+
  geom_rect(data=shade,mapping=aes(xmin=as.Date(x1), xmax=as.Date(x2), ymin=y1, ymax=y2),inherit.aes = F,fill='gray65',color = NA)+
  geom_line(data=subset(df, begin_date == "2003-09-01"),colour=colours[1],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2003-10-01"), colour=colours[2],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2003-11-01"), colour=colours[3],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2003-12-01"), colour=colours[4],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2004-01-01"), colour=colours[5],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2004-02-01"), colour=colours[6],linetype = "dashed")+
  geom_line(data=subset(df, begin_date == "2004-03-01"), colour=colours[7],linetype = "dashed")+
  geom_point(data=subset(df, begin_date == "2003-09-01"),color=colours[1], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2003-10-01"),color=colours[2], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2003-11-01"),color=colours[3], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2003-12-01"),color=colours[4], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2004-01-01"),color=colours[5], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2004-02-01"),color=colours[6], size=2,shape=15)+
  geom_point(data=subset(df, begin_date == "2004-03-01"),color=colours[7], size=2,shape=15)+
  theme_bw()+
  theme(
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    plot.title = element_blank())+
  coord_cartesian(xlim=c(as.Date("2003-09-01"),as.Date("2004-05-01")),ylim=c(0,0.65))







###################################################################################################

## transfer images to pdf
pdf(paste("F:/Thesis/Figures/3_Random_Forest/Re-forecasts_Analysis/Case_4/Examples_Forecasts_Report/Examples_Ensembles_Forecasts.pdf", sep=""),width=7.5,height=7,paper='special')

## define layout image
grid.arrange(Main,DR_2003,DR_2006,Main2,DR_2003_B,DR_2003_E,legend_plot,ncol=7,layout_matrix = rbind(c(1,1,1,1,2,2,NA),
                                                                                                     c(1,1,1,1,2,2,NA),
                                                                                                     c(1,1,1,1,2,2,NA),
                                                                                                     c(1,1,1,1,3,3,NA),
                                                                                                     c(1,1,1,1,3,3,NA),
                                                                                                     c(1,1,1,1,3,3,NA),
                                                                                                     c(NA,NA,NA,NA,NA,NA,NA),
                                                                                                     c(4,4,4,4,5,5,7),
                                                                                                     c(4,4,4,4,5,5,7),
                                                                                                     c(4,4,4,4,5,5,7),
                                                                                                     c(4,4,4,4,6,6,7),
                                                                                                     c(4,4,4,4,6,6,7),
                                                                                                     c(4,4,4,4,6,6,7)))
## close device
dev.off()


