###########################################################################################################
#### Script: MSc thesis Forecasting Drought Impacts
#### Date: 2019-03
#### Auther: Melati van der Weert
#### Supervisors: Samuel Sutanto, Henny van Lanen, and Niko Wanders
#### Chair group: Hydrology and Quantitative Water Management Group
#### University: Wageningen University & Research, the Netherlands
#### Objective: Illustrating forecasted drought impact occurance
#### Instructions: Go through the script step by step and execute the R-code (select code and Ctrl-R).
#### If required set the working folder, input folder, and output folder according to your specifications
###########################################################################################################


## set working directory
workdir <- "F:/Thesis/Scripts/Rstudio/4_Validation/Drought_Impact/0_Diff_Cases/Case_4/RF"
setwd(workdir)

## Load required packages
install.packages('ggplot2')
library(ggplot2)
install.packages('grid')
library(grid)
install.packages('gridExtra')
library(gridExtra)
library(RColorBrewer)

## function: defines date of date x months forward
add_months= function(date,n) seq(date, by = paste (n, "months"), length = 2)[2]

## names of the NUTS1 regions in Germany
list_NUTS_Names = c("SL","BW","BV","RP","TH","HE","SX","NW","BE","ST","HB","BB","HH","LS","MP","SH")
## numbers of the NUTS1 regions in Germany
list_NUTS = c("741","743","750","753","775","776","777","791","796","800","810","835","843","858","903","979")
list_NUTS = c("753","835")
## list of ensambles nameas
list_ensemble = c("p00","p01","p02","p03","p04","p05","p06","p07","p08","p09","p10","p11","p12","p13","p14")
## list of impact categories
list_category = c("Impact_Combined_1","Impact_Combined_2","Impact_Combined_3","Impact_Combined_4")
list_category = c("Impact_Combined_2","Impact_Combined_3")
## list of dates for wich forecast have been made
list_dates = format(seq(as.Date("2002-01-01"), as.Date("2010-12-01"), "month"), "%Y%m")


## create empty dataframe for resullts
df = data.frame ("LT"=integer(),"NUTS"=character(),"Impact"=character(), "date" = character() ,"median" = integer(),"lwr" = integer(),"upr" = integer(),"EDII" = integer())
shade = data.frame('x1'= character(), 'x2'= character(), 'y1'= integer(), 'y2'= integer(),"LT"=integer(),"NUTS"=character(),"fill"=character())


#### calculate BSS and ROC
## go trought every NUTS 1 level
for (NUTS in 1:length(list_NUTS)){ print(NUTS)
  ## go trought every impact category
  for (category in 1:length(list_category)){ 
    ## load proxy data wich incloud the proxy drought impact
    proxy = read.table(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Model_Input/Binary/",list_NUTS[NUTS],"/",list_category[category],".csv"),sep = ",",header=TRUE)
    ## create empty array needed to store data
    tmp.array = array(NA, dim = c(108,7,15))
    ## go trought every ensamble
    for (ensemble in 1:length(list_ensemble)){
      ## go trought every date
      for(date in 1:length(list_dates)){
        ## check if there is about for this perticalur situation -> if not there was no model built for this situation as the number of ipact reports were limited
        if(isTRUE(class(try(read.table(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Modelled_Drought_Impact/",list_ensemble[ensemble],"/",list_NUTS[NUTS],"/",list_category[category],"/",list_dates[date],".csv"),header = TRUE,sep = ","),TRUE))=="try-error")){
          tmp.array[date,,ensemble] = NA
        } else{
          ## load forecast
          forecast = read.table(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Modelled_Drought_Impact/",list_ensemble[ensemble],"/",list_NUTS[NUTS],"/",list_category[category],"/",list_dates[date],".csv"),header = TRUE,sep = ",")
          ## copy to empty array where all forecast for the perticalur NUTS region is merged into
          tmp.array[date,,ensemble] = forecast$x
        }
      }
    }

    ## average the ensemble values
    median=apply(tmp.array, c(1,2), median,na.rm=TRUE)
    lwr=apply(tmp.array, c(1,2), min,na.rm=TRUE)
    upr=apply(tmp.array, c(1,2), max,na.rm=TRUE)
    
    ## go trough every lead time of the forecast
    for(month in c(1,3,5)){
    #for(month in 1:7){
      
      ## define proxy and forecasted impact for every lead time for the whole case
      impact_proxy = proxy$Impact[(133-1+month):(240-1+month)]
      median_modelled = median[,month]
      lwr_modelled = lwr[,month]
      upr_modelled = upr[,month]
      
      ## state begin and end date
      begin_date = as.Date(paste0(proxy$Year[133-1+month],"-",proxy$Month[133-1+month],"-01"))
      end_date = as.Date(paste0(proxy$Year[240-1+month],"-",proxy$Month[240-1+month],"-01"))
      
      ## go trought the proxy of observe drought impact occurance
      if(is.na(sum(median))==FALSE){
        for (i in 1:length(impact_proxy)){
          if (impact_proxy[i]==1){
            ## state begin and end date
            start=add_months(begin_date,(i-1))
            end=add_months(begin_date,(i))
            
            ## define new row
            newRow <- data.frame("x1" = as.Date(start),"x2"=as.Date(end),"y1"=0,"y2"=1,"LT"=month,"NUTS"=list_NUTS[NUTS],"fill"="a")
            ## add new row to existing dataframe 
            shade=rbind(shade,newRow)
            
            ## print
            print(start)
            print(month)
            print(list_NUTS[NUTS])
          }
        }
      }
      

      if(is.na(sum(median_modelled))){
      }else{
        
        ## create empty dataframe needed to plot in ggplot
        df1 = data.frame ("LT"=array(month,c(108)),"NUTS"=array(list_NUTS[NUTS],c(108)),
                          "Impact"=array(list_category[category]), 
                          "date" = seq(begin_date, end_date, "months") ,"median" = median_modelled,"lwr" = lwr_modelled,"upr" = upr_modelled,"EDII" = impact_proxy)
        ## merge dataframes
        df=rbind(df,df1)
        
      }
    }
  }
}

## location to where the image is saved
pdf(paste0('F:/Thesis/Figures/3_Random_Forest/Re-forecasts_Analysis/Case_4/Examples_Forecasts_Report/Examples_Median_Forecasts.pdf'),width=7,height=6,paper='special')

## create illustration
p = ggplot(df, aes(date, median,lty = ' Median Drought Impact\n Forecast with Ensemble Range'))+
  geom_rect(data=shade,mapping=aes(xmin=as.Date(x1), xmax=as.Date(x2), ymin=y1, ymax=y2,fill="Observed"),inherit.aes = F)+
  geom_ribbon(data=df,aes(ymin=lwr,ymax=upr),fill="red",alpha=0.25)+
  geom_line(aes(y = median),colour = "darkred",size=0.6)+
  scale_y_continuous(expand = c(0, 0))+
  scale_x_date(expand = c(0, 0))+
  ylab("Likelihood of Impact Occurance (LIO)")+
  xlab("Date")+
  facet_wrap(NUTS~LT) +
  facet_grid(NUTS~LT,   labeller = labeller(
    NUTS = c(`753` = "A. Energy & Industry + Transportation\n+ Public Water Supply\n\n NUTS1: RP", `835` = "B. Water Quality+ Freshwater\n Ecosystem + Terrestrial Ecosystem\n\n NUTS1: BB"),
    LT = c(`1` = "LT=1", `3` = "LT=3", `5` = "LT=5")))+
  theme(panel.spacing = unit(1.7, "lines"),
        axis.title.x = element_blank(),
        legend.position="bottom",
        legend.title = element_blank())+
  scale_fill_manual(values = alpha(c("gray65"), 1))
  
## plot illustration
plot(p)

## close window
dev.off()
