###########################################################################################################
#### Script: MSc thesis Forecasting Drought Impacts
#### Date: 2019-03
#### Auther: Melati van der Weert
#### Supervisors: Samuel Sutanto, Henny van Lanen, and Niko Wanders
#### Chair group: Hydrology and Quantitative Water Management Group
#### University: Wageningen University & Research, the Netherlands
#### Objective: Illustrating predictor importance
#### Instructions: Go through the script step by step and execute the R-code (select code and Ctrl-R).
#### If required set the working folder, input folder, and output folder according to your specifications
###########################################################################################################


## set working directory
workdir <- "F:/Thesis/Scripts/Rstudio/3_Random_Forest/Re-forecasts_Analysis/Case_4/5_Plot_Rank_Predictor_Importance_Report"
setwd(workdir)

## Load required packages
library(readr)
library(randomForest)
library(lattice)
library(ggplot2)
library(RColorBrewer)
library(grid)
library(gridExtra)
library(caret)
library(dplyr)
library("ggExtra")
library(grid)
library(gtable)
library("caret")


## list of predictors position x of table
predictors <- c("SPI_1","SPI_3","SPI_6","SPI_12","SPEI_1","SPEI_3","SPEI_6","SPEI_12","SRI_1","SRI_3","SRI_6","SRI_12","Month","Year")
## list of predictors position x of table
indicies <- c("SPI-x","SPI-x","SPI-x","SPI-x","SPEI-x","SPEI-x","SPEI-x","SPEI-x","SRI-x","SRI-x","SRI-x","SRI-x"," "," ")
## list of NUTS regions position y of table
list_NUTS <- c("741","743","750","753","775","776","777","791","796","800","810","835","843","858","903","979")
## list of NUTS regions position y of table
list_NUTS1 = c("SL","BW","BV","RP","TH","HE","SX","NW","BE","ST","HB","BB","HH","LS","MP","SH")


## go trought thde diffrent combined categories
for(category in 1:4){
  df = data.frame ("Indicies" = character(),"Predictor" = character(),"NUTS" = character(),"Rank" = integer())
  ## go trough every NUTS region
  for (NUTS in 1:length(list_NUTS)){ 
    ## open RF model if it exsits
    if(isTRUE(class(try(readRDS(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Model/",list_NUTS[NUTS],"/Impact_Combined_",category,".rds")),TRUE))=="try-error")){
      for (rank in 1:length(predictors)){
        ## create new row with data
        newRow <- data.frame("Indicies" = indicies[rank],"Predictor" = predictors[rank],"NUTS" = list_NUTS1[NUTS],"Rank" = NA)
        ## merge new row with existing dataframe
        df=rbind(df,newRow)
      }
    } else{
      ## define the model
      model <- readRDS(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Model/",list_NUTS[NUTS],"/Impact_Combined_",category,".rds"))
      ## go trough the ranks
      for (rank in 1:length(predictors)){
        ## create new row with data
        newRow <- data.frame("Indicies" = indicies[rank],"Predictor" = predictors[rank],"NUTS" = list_NUTS1[NUTS],"Rank" = as.numeric(rank(varImp(model)[1])[rank]))
        ## merge new row with existing dataframe
        df=rbind(df,newRow)
      }
    }
  }
  ## gif names to dataframes
  assign(paste0("data",category),df)
  
}


## create rank image for combined imact 1
p1 = ggplot(data = data1, aes(x=Predictor, y=NUTS, fill=Rank)) + 
  geom_tile()+
  facet_grid(~ Indicies, space="free_x", scales="free_x", switch="x")+ 
  scale_fill_gradient(low = "#F5FBB0", high =  "#D7191C",
                      breaks=c(0,14),labels=c("Low","High"),limits=c(0,14))+
  scale_y_discrete(expand = c(0, 0))+
  scale_x_discrete(expand = c(0, 0),labels=c("SPI_1"="1","SPI_3"="3","SPI_6"="6","SPI_12"="12","SPEI_1"="1","SPEI_3"="3","SPEI_6"="6","SPEI_12"="12","SRI_1"="1","SRI_3"="3","SRI_6"="6","SRI_12"="12","Month"="M","Year"="Y"))+
  ylab("NUTS-1 Regions")+
  theme_bw() +
  theme(strip.placement = "outside",
        strip.text=element_text(vjust=2.5,hjust=0.55,size=7.5),
        axis.title.x = element_blank(),
        #axis.title.y = element_blank(),
        axis.text.x=element_text(size=6.5),
        axis.text.y=element_text(size=6.5),
        plot.margin=unit(c(0,0.15,0.15,0.15), "cm"),
        strip.background = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.border = element_rect(colour="grey30"),
        panel.spacing=unit(0.2,"cm"),
        legend.position="none")


data1_hist <- data1 %>%
  select(Predictor, Rank,Indicies) %>%
  group_by(Predictor,Indicies) %>%
  summarise(Rank = mean(Rank,na.rm=TRUE))


pp1 <-ggplot(data=data1_hist, aes(x=Predictor, y=Rank)) +
  geom_bar(stat="identity",width=1,color="grey40", fill="gray")+
  facet_grid(~ Indicies, space="free_x", scales="free_x", switch="x")+
  #facet_grid(. ~ paste0("Combined Impact 1")) +
  scale_y_discrete(expand = c(0, 0),breaks=c(1,max(data1_hist$Rank)-1),labels=c("Low", "High"),limit = c(1, max(data1_hist$Rank)-1))+
  scale_x_discrete(expand = c(0, 0),labels=c("SPI_1"="1","SPI_3"="3","SPI_6"="6","SPI_12"="12","SPEI_1"="1","SPEI_3"="3","SPEI_6"="6","SPEI_12"="12","SRI_1"="1","SRI_3"="3","SRI_6"="6","SRI_12"="12","Month"="M","Year"="Y"))+
  theme(
    panel.spacing=unit(0.2,"cm"),
    strip.placement = "outside",
    axis.line = element_line(colour = "black"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x=element_text(size=6.5),
    axis.text.y=element_text(size=6.5),
    #axis.text.y = element_blank(),
    #axis.text.x = element_blank(),
    #axis.ticks.x = element_blank(),
    axis.ticks.y = element_blank(),
    panel.background = element_blank(),
    plot.margin=unit(c(0.15,0.15,0.05,0.15), "cm"),
    strip.background = element_blank(),
    strip.text = element_blank(),
    legend.position="none")

z1 <- ggplotGrob(pp1)

#  New strip at the top
z1 <- gtable_add_rows(z1, z1$height[8]*2, pos = 6)  # New row added below row 6

z1 <- gtable_add_grob(z1, 
                     list(rectGrob(gp = gpar(col = NA, fill = "gray85", size = 0.35)),
                          textGrob("A. Agriculture and Livestock Farming\n+ Forestry", gp = gpar(cex = .7, col = "black"))), 
                     t=7, l=5, b=7, r=11, name = c("a", "b"))

# Add small gap between strips - below row 6
z1 <- gtable_add_rows(z1, unit(6.5/10, "line"), 7)


##############################

## create rank image for combined imact 2
p2 = ggplot(data = data2, aes(x=Predictor, y=NUTS, fill=Rank)) + 
  geom_tile()+
  facet_grid(~ Indicies, space="free_x", scales="free_x", switch="x")+ 
  scale_fill_gradient(low = "#F5FBB0", high =  "#D7191C",
                      breaks=c(0,14),labels=c("Low","High"),limits=c(0,14))+
  scale_y_discrete(expand = c(0, 0))+
  scale_x_discrete(expand = c(0, 0),labels=c("SPI_1"="1","SPI_3"="3","SPI_6"="6","SPI_12"="12","SPEI_1"="1","SPEI_3"="3","SPEI_6"="6","SPEI_12"="12","SRI_1"="1","SRI_3"="3","SRI_6"="6","SRI_12"="12","Month"="M","Year"="Y"))+
  theme_bw() +
  theme(strip.placement = "outside",
        strip.text=element_text(vjust=2.5,hjust=0.55,size=7.5),
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        axis.text.x=element_text(size=6.5),
        axis.text.y=element_text(size=6.5),
        plot.margin=unit(c(0,0.15,0.15,0.15), "cm"),
        strip.background = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.border = element_rect(colour="grey30"),
        panel.spacing=unit(0.2,"cm"),
        legend.position="none")


data2_hist <- data2 %>%
  select(Predictor, Rank,Indicies) %>%
  group_by(Predictor,Indicies) %>%
  summarise(Rank = mean(Rank,na.rm=TRUE))


pp2 <-ggplot(data=data2_hist, aes(x=Predictor, y=Rank)) +
  geom_bar(stat="identity",width=1,color="grey40", fill="gray")+
  facet_grid(~ Indicies, space="free_x", scales="free_x", switch="x")+
  #facet_grid(. ~ paste0("Combined Impact 1")) +
  scale_y_discrete(expand = c(0, 0),breaks=c(1,max(data1_hist$Rank)-1),labels=c("Low", "High"),limit = c(1, max(data1_hist$Rank)-1))+
  scale_x_discrete(expand = c(0, 0),labels=c("SPI_1"="1","SPI_3"="3","SPI_6"="6","SPI_12"="12","SPEI_1"="1","SPEI_3"="3","SPEI_6"="6","SPEI_12"="12","SRI_1"="1","SRI_3"="3","SRI_6"="6","SRI_12"="12","Month"="M","Year"="Y"))+
  theme(
    panel.spacing=unit(0.2,"cm"),
    strip.placement = "outside",
    axis.line = element_line(colour = "black"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x=element_text(size=6.5),
    axis.text.y=element_text(size=6.5),
    panel.background = element_blank(),
    plot.margin=unit(c(0.15,0.15,0.05,0.15), "cm"),
    strip.background = element_blank(),
    strip.text = element_blank(),
    legend.position="none")

z2 <- ggplotGrob(pp2)

#  New strip at the top
z2 <- gtable_add_rows(z2, z2$height[8]*2, pos = 6)  # New row added below row 6

z2 <- gtable_add_grob(z2, 
                     list(rectGrob(gp = gpar(col = NA, fill = "gray85", size = 0.35)),
                          textGrob("B. Energy & Industry + Transportation\n+ Public Water Supply", gp = gpar(cex = .7, col = "black"))), 
                     t=7, l=5, b=7, r=11, name = c("a", "b"))

# Add small gap between strips - below row 6
z2 <- gtable_add_rows(z2, unit(6.5/10, "line"), 7)


##############################

## create rank image for combined imact 3
p3 = ggplot(data = data3, aes(x=Predictor, y=NUTS, fill=Rank)) + 
  geom_tile()+
  facet_grid(~ Indicies, space="free_x", scales="free_x", switch="x")+ 
  scale_fill_gradient(low = "#F5FBB0", high =  "#D7191C",
                      breaks=c(0,14),labels=c("Low","High"),limits=c(0,14))+
  scale_y_discrete(expand = c(0, 0))+
  scale_x_discrete(expand = c(0, 0),labels=c("SPI_1"="1","SPI_3"="3","SPI_6"="6","SPI_12"="12","SPEI_1"="1","SPEI_3"="3","SPEI_6"="6","SPEI_12"="12","SRI_1"="1","SRI_3"="3","SRI_6"="6","SRI_12"="12","Month"="M","Year"="Y"))+
  ylab("NUTS-1 Regions")+
  theme_bw() +
  theme(strip.placement = "outside",
        strip.text=element_text(vjust=2.5,hjust=0.55,size=7.5),
        axis.title.x = element_blank(),
        #axis.title.y = element_blank(),
        axis.text.x=element_text(size=6.5),
        axis.text.y=element_text(size=6.5),
        plot.margin=unit(c(0,0.15,0.15,0.15), "cm"),
        strip.background = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.border = element_rect(colour="grey30"),
        panel.spacing=unit(0.2,"cm"),
        legend.position="none")


data3_hist <- data3 %>%
  select(Predictor, Rank,Indicies) %>%
  group_by(Predictor,Indicies) %>%
  summarise(Rank = mean(Rank,na.rm=TRUE))


pp3 <-ggplot(data=data3_hist, aes(x=Predictor, y=Rank)) +
  geom_bar(stat="identity",width=1,color="grey40", fill="gray")+
  facet_grid(~ Indicies, space="free_x", scales="free_x", switch="x")+
  #facet_grid(. ~ paste0("Combined Impact 1")) +
  scale_y_discrete(expand = c(0, 0),breaks=c(1,max(data1_hist$Rank)-1),labels=c("Low", "High"),limit = c(1, max(data1_hist$Rank)-1))+
  scale_x_discrete(expand = c(0, 0),labels=c("SPI_1"="1","SPI_3"="3","SPI_6"="6","SPI_12"="12","SPEI_1"="1","SPEI_3"="3","SPEI_6"="6","SPEI_12"="12","SRI_1"="1","SRI_3"="3","SRI_6"="6","SRI_12"="12","Month"="M","Year"="Y"))+
  theme(
    panel.spacing=unit(0.2,"cm"),
    strip.placement = "outside",
    axis.line = element_line(colour = "black"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x=element_text(size=6.5),
    axis.text.y=element_text(size=6.5),
    axis.ticks.y = element_blank(),
    panel.background = element_blank(),
    plot.margin=unit(c(0.15,0.15,0.05,0.15), "cm"),
    strip.background = element_blank(),
    strip.text = element_blank(),
    legend.position="none")

z3 <- ggplotGrob(pp3)

#  New strip at the top
z3 <- gtable_add_rows(z3, z3$height[8]*2, pos = 6)  # New row added below row 6

z3 <- gtable_add_grob(z3, 
                      list(rectGrob(gp = gpar(col = NA, fill = "gray85", size = 0.35)),
                           textGrob("C. Water Quality + Freshwater\nEcosystem + Terrestrial Ecosystem", gp = gpar(cex = .7, col = "black"))), 
                      t=7, l=5, b=7, r=11, name = c("a", "b"))

# Add small gap between strips - below row 6
z3 <- gtable_add_rows(z3, unit(6.5/10, "line"), 7)


##############################

## create rank image for combined imact 4
p4 = ggplot(data = data4, aes(x=Predictor, y=NUTS, fill=Rank)) + 
  geom_tile()+
  facet_grid(~ Indicies, space="free_x", scales="free_x", switch="x")+ 
  scale_fill_gradient(low = "#F5FBB0", high =  "#D7191C",
                      breaks=c(0,14),labels=c("Low","High"),limits=c(0,14))+
  scale_y_discrete(expand = c(0, 0))+
  scale_x_discrete(expand = c(0, 0),labels=c("SPI_1"="1","SPI_3"="3","SPI_6"="6","SPI_12"="12","SPEI_1"="1","SPEI_3"="3","SPEI_6"="6","SPEI_12"="12","SRI_1"="1","SRI_3"="3","SRI_6"="6","SRI_12"="12","Month"="M","Year"="Y"))+
  theme_bw() +
  labs(fill = "Predictor \nImportance")+
  theme(strip.placement = "outside",
        strip.text=element_text(vjust=2.5,hjust=0.55,size=7.5),
        axis.title.x = element_blank(),
        axis.text.x=element_text(size=6.5),
        axis.text.y=element_text(size=6.5),
        axis.title.y = element_blank(),
        plot.margin=unit(c(0,0.15,0.15,0.15), "cm"),
        strip.background = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.border = element_rect(colour="grey30"),
        panel.spacing=unit(0.2,"cm"),
        legend.title = element_text(size = 8),
        legend.text=element_text(size = 8),
        legend.key.size = unit(1,"line"))



data4_hist <- data4 %>%
  select(Predictor, Rank,Indicies) %>%
  group_by(Predictor,Indicies) %>%
  summarise(Rank = mean(Rank,na.rm=TRUE))


pp4 <-ggplot(data=data4_hist, aes(x=Predictor, y=Rank)) +
  geom_bar(stat="identity",width=1,color="grey40", fill="gray")+
  facet_grid(~ Indicies, space="free_x", scales="free_x", switch="x")+
  #facet_grid(. ~ paste0("Combined Impact 1")) +
  scale_y_discrete(expand = c(0, 0),breaks=c(1,max(data1_hist$Rank)-1),labels=c("Low", "High"),limit = c(1, max(data1_hist$Rank)-1))+
  scale_x_discrete(expand = c(0, 0),labels=c("SPI_1"="1","SPI_3"="3","SPI_6"="6","SPI_12"="12","SPEI_1"="1","SPEI_3"="3","SPEI_6"="6","SPEI_12"="12","SRI_1"="1","SRI_3"="3","SRI_6"="6","SRI_12"="12","Month"="M","Year"="Y"))+
  theme(
    panel.spacing=unit(0.2,"cm"),
    strip.placement = "outside",
    axis.line = element_line(colour = "black"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x=element_text(size=6.5),
    axis.text.y=element_text(size=6.5),
    axis.ticks.y = element_blank(),
    panel.background = element_blank(),
    plot.margin=unit(c(0.15,0.15,0.05,0.15), "cm"),
    strip.background = element_blank(),
    strip.text = element_blank(),
    legend.position="none")

z4 <- ggplotGrob(pp4)

#  New strip at the top
z4 <- gtable_add_rows(z4, z4$height[8]*2, pos = 6)  # New row added below row 6

z4 <- gtable_add_grob(z4, 
                      list(rectGrob(gp = gpar(col = NA, fill = "gray85", size = 0.35)),
                           textGrob("D. Wildfire + Air Quality +\nHuman Health & Public Safety", gp = gpar(cex = .7, col = "black"))), 
                      t=7, l=5, b=7, r=11, name = c("a", "b"))

# Add small gap between strips - below row 6
z4 <- gtable_add_rows(z4, unit(6.5/10, "line"), 7)


#####################################################################

## set paper size
w=7.5
h=10

## loacation to save illustration
pdf(paste0("F:/Thesis/Figures/3_Random_Forest/Re-forecasts_Analysis/Case_4/Rank_Predictor_Importance/Rank_Case_4.pdf"),width=w,height=h,paper='special')

## define layout image
grid.arrange(z1,z2,p1,p2,z3,z4,p3,p4,ncol = 6,
             widths=unit(c(w*0.021,w*0.005,w*0.43,w*0.005,w*0.43,w*0.115),c("in","in","in","in","in")),
             heights=unit(c(h*0.15,h*0.35,h*0.15,h*0.35),c("in","in","in","in","in")),
             layout_matrix = rbind(c(NA,1,1,2,2,NA),
                                   c(3,3,3,NA,4,NA),
                                   c(NA,5,5,6,6,NA),
                                   c(7,7,7,NA,8,8)))

## close window
dev.off()

