library(readr)
library(lattice)
library(ggplot2)
library(RColorBrewer)
library(grid)
library(gridExtra)
library("scales")


## number and names of the NUTS1 regions in Germany
list_NUTS = c("741","743","750","753","775","776","777","791","796","800","810","835","843","858","903","979")

## make empty table for results of ranked predictors

data <- data.frame(matrix(ncol = 3, nrow = 64))
z <- c("NUTS","LT","skill")
colnames(data) <- z

BSS = read.table("F:/Thesis/Data/4_Validation/Drought_Impact/0_Diff_Cases/Case_4/RF/BSS.csv",header = TRUE,sep = ",")
ROC = read.table("F:/Thesis/Data/4_Validation/Drought_Impact/0_Diff_Cases/Case_4/RF/ROC.csv",header = TRUE,sep = ",")

for(category in 1:4){
  print(paste0(category,"##################"))
  data_BSS <- data.frame(matrix(ncol = 3, nrow = 112))
  z <- c("NUTS","LT","skill")
  colnames(data_BSS) <- z
  
  data_ROC <- data.frame(matrix(ncol = 3, nrow = 112))
  z <- c("NUTS","LT","skill")
  colnames(data_ROC) <- z
  ## go trough every NUTS region
  for (NUTS in 1:length(list_NUTS)){
    data_BSS$NUTS[((NUTS-1)*7+1):(NUTS*7)]=list_NUTS[NUTS]
    data_BSS$LT[((NUTS-1)*7+1):(NUTS*7)]=1:7
    data_BSS$skill[((NUTS-1)*7+1):(NUTS*7)]=as.numeric(round(BSS[(NUTS-1)*4+category,2:8], digits = 2))
    
    print(category*NUTS)
    
    data_ROC$NUTS[((NUTS-1)*7+1):(NUTS*7)]=list_NUTS[NUTS]
    data_ROC$LT[((NUTS-1)*7+1):(NUTS*7)]=1:7
    data_ROC$skill[((NUTS-1)*7+1):(NUTS*7)]=as.numeric(round(ROC[(NUTS-1)*4+category,2:8], digits = 2))
  }
  data_BSS$skill1=data_BSS$skill
  data_BSS$skill1[is.na(data_BSS$skill1)]=-999
  data_BSS$skill2 <- cut(data_BSS$skill1,breaks = c(-Inf,-10,-0.5,0,0.5,1),right = FALSE)
  
  data_ROC$skill1=data_ROC$skill
  data_ROC$skill1[is.na(data_ROC$skill1)]=-999
  data_ROC$skill2 <- cut(data_ROC$skill1,breaks = c(-Inf,0,0.5,0.7,0.8,1),right = FALSE)
  
  assign(paste0("result_BSS_",category),data_BSS)
  assign(paste0("result_ROC_",category),data_ROC)
}


## plot skill models
p1 = ggplot(data = result_BSS_1, aes(x=LT, y=NUTS, fill=skill2)) + 
  geom_tile()+ 
  geom_tile(color="white", size=0.0001)+
  geom_text(aes(label = skill))+
  scale_fill_manual(breaks=c("[-Inf,-10)","[-10,-0.5)", "[-0.5,0)", "[0,0.5)","[0.5,1)"),
                    labels=c("No Data","Bad","Poor","Acceptable","Good"),
                    values = c("gray48","#D7191C","#FDAE61","#ABDDA4", "#2B83BA"),
                                drop=FALSE)+
  facet_grid(. ~ paste0("Combined Impact 1")) +
    theme(
      axis.text.x = element_blank(),
      axis.ticks.x = element_blank(),
      axis.title.x = element_blank(),
      axis.title.y = element_blank(),
      legend.title = element_blank(),
      legend.position="none")

p2 = ggplot(data = result_BSS_2, aes(x=LT, y=NUTS, fill=skill2)) + 
  geom_tile()+ 
  geom_tile(color="white", size=0.0001)+
  geom_text(aes(label = skill))+
  scale_fill_manual(breaks=c("[-Inf,-10)","[-10,-0.5)", "[-0.5,0)", "[0,0.5)","[0.5,1)"),
                    labels=c("No Data","Bad","Poor","Acceptable","Good"),
                    values = c("gray48","#D7191C","#FDAE61","#ABDDA4", "#2B83BA"),
                    drop=FALSE)+
  facet_grid(. ~ paste0("Combined Impact 2")) +
  theme(
    axis.text.x = element_blank(),
    axis.ticks.x = element_blank(),
    axis.text.y = element_blank(),
    axis.ticks.y = element_blank(),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    legend.title = element_blank(),
    legend.position="none")

p3 = ggplot(data = result_BSS_3, aes(x=LT, y=NUTS, fill=skill2)) + 
  geom_tile()+ 
  xlab("LT")+
  geom_tile(color="white", size=0.0001)+
  geom_text(aes(label = skill))+
  scale_fill_manual(breaks=c("[-Inf,-10)","[-10,-0.5)", "[-0.5,0)", "[0,0.5)","[0.5,1)"),
                    labels=c("No Data","Bad","Poor","Acceptable","Good"),
                    values = c("gray48","#D7191C","#FDAE61","#ABDDA4", "#2B83BA"),
                    drop=FALSE)+
  facet_grid(. ~ paste0("Combined Impact 3")) +
  theme(
    axis.title.y = element_blank(),
    legend.title = element_blank(),
    legend.position="none")+
  scale_x_continuous("LT", labels = as.character(1:7), breaks = 1:7)

p4 = ggplot(data = result_BSS_4, aes(x=LT, y=NUTS, fill=skill2)) + 
  geom_tile()+ 
  xlab("LT")+
  geom_tile(color="white", size=0.0001)+
  geom_text(aes(label = skill))+
  scale_fill_manual(breaks=c("[-Inf,-10)","[-10,-0.5)", "[-0.5,0)", "[0,0.5)","[0.5,1)"),
                    labels=c("No Data","Bad","Poor","Acceptable","Good"),
                    values = c("gray48","#D7191C","#FDAE61","#ABDDA4", "#2B83BA"),
                    drop=FALSE)+
  facet_grid(. ~ paste0("Combined Impact 3")) +
  theme(
    axis.text.y = element_blank(),
    axis.ticks.y = element_blank(),
    axis.title.y = element_blank(),
    legend.title = element_blank())+
  scale_x_continuous("LT", labels = as.character(1:7), breaks = 1:7)



w=9
h=8

pdf(paste0("F:/Thesis/Figures/4_Validation/Drought_Impact/0_Diff_Cases/Case_4/Skill/BSS.pdf"),width=w,height=h,paper='special')

grid.arrange(p1,p2,p3,p4, ncol = 3,
             heights=unit(c(h*0.5,h*0.5), c("in", "in")),
             widths=unit(c(w*0.42,w*0.42,w*0.13), c("in", "in")),
             layout_matrix = rbind(c(1, 2, NA),
                                   c(3, 4, 4)))
dev.off()

############################################################################################

## plot skill models
p1 = ggplot(data = result_ROC_1, aes(x=LT, y=NUTS, fill=skill2)) + 
  geom_tile()+ 
  geom_tile(color="white", size=0.0001)+
  geom_text(aes(label = skill))+
  scale_fill_manual(breaks=c("[-Inf,0)","[0,0.5)", "[0.5,0.7)", "[0.7,0.8)","[0.8,1)"),
                    labels=c("No Data","Bad","Poor","Acceptable","Good"),
                    values = c("gray48","#D7191C","#FDAE61","#ABDDA4", "#2B83BA"),
                    drop=FALSE)+
  facet_grid(. ~ paste0("Combined Impact 1")) +
  theme(
    axis.text.x = element_blank(),
    axis.ticks.x = element_blank(),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    legend.title = element_blank(),
    legend.position="none")

p2 = ggplot(data = result_ROC_2, aes(x=LT, y=NUTS, fill=skill2)) + 
  geom_tile()+ 
  geom_tile(color="white", size=0.0001)+
  geom_text(aes(label = skill))+
  scale_fill_manual(breaks=c("[-Inf,0)","[0,0.5)", "[0.5,0.7)", "[0.7,0.8)","[0.8,1)"),
                    labels=c("No Data","Bad","Poor","Acceptable","Good"),
                    values = c("gray48","#D7191C","#FDAE61","#ABDDA4", "#2B83BA"),
                    drop=FALSE)+
  facet_grid(. ~ paste0("Combined Impact 2")) +
  theme(
    axis.text.x = element_blank(),
    axis.ticks.x = element_blank(),
    axis.text.y = element_blank(),
    axis.ticks.y = element_blank(),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    legend.title = element_blank(),
    legend.position="none")

p3 = ggplot(data = result_ROC_3, aes(x=LT, y=NUTS, fill=skill2)) + 
  geom_tile()+ 
  xlab("LT")+
  geom_tile(color="white", size=0.0001)+
  geom_text(aes(label = skill))+
  scale_fill_manual(breaks=c("[-Inf,0)","[0,0.5)", "[0.5,0.7)", "[0.7,0.8)","[0.8,1)"),
                    labels=c("No Data","Bad","Poor","Acceptable","Good"),
                    values = c("gray48","#D7191C","#FDAE61","#ABDDA4", "#2B83BA"),
                    drop=FALSE)+
  facet_grid(. ~ paste0("Combined Impact 3")) +
  theme(
    axis.title.y = element_blank(),
    legend.title = element_blank(),
    legend.position="none")+
  scale_x_continuous("LT", labels = as.character(1:7), breaks = 1:7)

p4 = ggplot(data = result_ROC_4, aes(x=LT, y=NUTS, fill=skill2)) + 
  geom_tile()+ 
  xlab("LT")+
  geom_tile(color="white", size=0.0001)+
  geom_text(aes(label = skill))+
  scale_fill_manual(breaks=c("[-Inf,0)","[0,0.5)", "[0.5,0.7)", "[0.7,0.8)","[0.8,1)"),
                    labels=c("No Data","Bad","Poor","Acceptable","Good"),
                    values = c("gray48","#D7191C","#FDAE61","#ABDDA4", "#2B83BA"),
                    drop=FALSE)+
  facet_grid(. ~ paste0("Combined Impact 4")) +
  theme(
    axis.text.y = element_blank(),
    axis.ticks.y = element_blank(),
    axis.title.y = element_blank(),
    legend.title = element_blank())+
  scale_x_continuous("LT", labels = as.character(1:7), breaks = 1:7)

w=9
h=8

pdf(paste0("F:/Thesis/Figures/4_Validation/Drought_Impact/0_Diff_Cases/Case_4/Skill/ROC.pdf"),width=w,height=h,paper='special')

grid.arrange(p1,p2,p3,p4, ncol = 3,
             heights=unit(c(h*0.5,h*0.5), c("in", "in")),
             widths=unit(c(w*0.42,w*0.42,w*0.13), c("in", "in")),
             layout_matrix = rbind(c(1, 2, NA),
                                   c(3, 4, 4)))
dev.off()
