library(readr)
library(lattice)
library(ggplot2)
library(RColorBrewer)
library(grid)
library(gridExtra)
library("scales")


## number and names of the NUTS1 regions in Germany
list_NUTS = c("741","743","750","753","775","776","777","791","796","800","810","835","843","858","903","979")
list_NUTS1 = c("SL","BW","BV","RP","TH","HE","SX","NW","BE","ST","HB","BB","HH","LS","MP","SH")



## list of skill scores
list_criteria = c("ROC")

## make empty table for results of ranked predictors
data = data.frame("NUTS"= character(), "LT"= integer(),"category"= integer(), "skill"= integer(), "criteria"= character())

BSS = read.table("F:/Thesis/Data/4_Validation/Drought_Impact/0_Diff_Cases/Case_4/RF_Factor/BSS_Year_No.csv",header = TRUE,sep = ",")
ROC = read.table("F:/Thesis/Data/4_Validation/Drought_Impact/0_Diff_Cases/Case_4/RF_Factor/ROC_Year_No.csv",header = TRUE,sep = ",")

for(criteria in list_criteria){

  ## go trough every NUTS region
  for (NUTS in 1:length(list_NUTS)){
    for(LT in 1:7){
      
      for(category in 1:4){
          
        newRow <- data.frame("NUTS"= list_NUTS1[NUTS], "LT"= LT, "category"= category, "skill"= eval(parse(text=paste0("as.numeric(round(",criteria,"[(",NUTS,"-1)*4+",category,",",LT,"+1], digits = 1))"))), "criteria"= criteria)
        data=rbind(data,newRow)

      }
    }  
  }
}
  
data$skill1=data$skill
data$skill1[is.na(data$skill1)]=-999

data$skill2=data$skill1

data$skill2[1:448] <- cut(data$skill1[1:448],breaks = c(-Inf,0,0.5,0.7,0.8,1.1),right = FALSE)


data$skill2[1:448] [data$skill2[1:448]  == "[-Inf,0)"] <- "No Data"
data$skill2[1:448] [data$skill2[1:448]  == "[0,0.5)"] <- "Bad"
data$skill2[1:448] [data$skill2[1:448]  == "[0.5,0.7)"] <- "Poor"
data$skill2[1:448] [data$skill2[1:448]  == "[0.7,0.8)"] <- "Acceptable"
data$skill2[1:448] [data$skill2[1:448]  == "[0.8,1.1)"] <- "Good"


pdf(paste('F:/Thesis/Figures/4_Validation/Drought_Impact/0_Diff_Cases/Case_4/Skill/Case_4_Skill_ROC_Year_No.pdf', sep=""),width=7,height=3.9,paper='special')

p = ggplot(data, aes(x=LT, y=NUTS, fill=skill2)) + 
  geom_tile()+ 
  scale_y_discrete(expand = c(0, 0))+
  xlab("LT [months]")+
  ylab("NUTS-1 Region")+
  scale_x_continuous(expand = c(0, 0),breaks = c(1,2,3,4,5,6,7))+
  geom_tile(color="white", size=0.0001)+
  geom_text(aes(label = skill), size=2.2)+
  facet_grid(~category,   labeller = labeller(
    category = c(`1` = "A. Agriculture and\n Livestock Farming\n+ Forestry", `2` = "B. Energy & Industry\n+ Transportation\n+ Public Water Supply",`3` = "C. Water Quality\n+ Freshwater Ecosystem\n + Terrestrial Ecosystem", `4` = "D. Wildfire + Air Quality\n + Humane Health\n & Public Safety")))+
  scale_fill_manual(labels=c(" No Data  "," Fail  "," Poor  "," Fair  "," Good  "),
                    values = c("gray48","#D73026","#FDAD60", "#A5D86A","#199850"),
                    drop=FALSE)+
  theme(legend.title = element_blank(),
        strip.text = element_text(size = 8),
        axis.title = element_text(size = 9),
        axis.text=element_text(size = 7),
        legend.text=element_text(size = 8),
        legend.key.size = unit(0.75,"line"),
        legend.position="bottom")


plot(p)

dev.off()    
    
    
# 
# 
# ## plot skill models
# p1 = ggplot(data = result_BSS_1, aes(x=LT, y=NUTS, fill=skill2)) + 
#   geom_tile()+ 
#   geom_tile(color="white", size=0.0001)+
#   geom_text(aes(label = skill))+
#   scale_fill_manual(breaks=c("[-Inf,-10)","[-10,-0.5)", "[-0.5,0)", "[0,0.5)","[0.5,1)"),
#                     labels=c("No Data","Bad","Poor","Acceptable","Good"),
#                     values = c("gray48","#D73026","#FDAD60", "#A5D86A","#199850"),
#                                 drop=FALSE)+
#   facet_grid(. ~ paste0("Combined Impact 1")) +
#     theme(
#       axis.text.x = element_blank(),
#       axis.ticks.x = element_blank(),
#       axis.title.x = element_blank(),
#       axis.title.y = element_blank(),
#       legend.title = element_blank(),
#       legend.position="none")
# 
# p2 = ggplot(data = result_BSS_2, aes(x=LT, y=NUTS, fill=skill2)) + 
#   geom_tile()+ 
#   geom_tile(color="white", size=0.0001)+
#   geom_text(aes(label = skill))+
#   scale_fill_manual(breaks=c("[-Inf,-10)","[-10,-0.5)", "[-0.5,0)", "[0,0.5)","[0.5,1)"),
#                     labels=c("No Data","Bad","Poor","Acceptable","Good"),
#                     values = c("gray48","#D73026","#FDAD60", "#A5D86A","#199850"),
#                     drop=FALSE)+
#   facet_grid(. ~ paste0("Combined Impact 2")) +
#   theme(
#     axis.text.x = element_blank(),
#     axis.ticks.x = element_blank(),
#     axis.text.y = element_blank(),
#     axis.ticks.y = element_blank(),
#     axis.title.x = element_blank(),
#     axis.title.y = element_blank(),
#     legend.title = element_blank(),
#     legend.position="none")
# 
# p3 = ggplot(data = result_BSS_3, aes(x=LT, y=NUTS, fill=skill2)) + 
#   geom_tile()+ 
#   xlab("LT")+
#   geom_tile(color="white", size=0.0001)+
#   geom_text(aes(label = skill))+
#   scale_fill_manual(breaks=c("[-Inf,-10)","[-10,-0.5)", "[-0.5,0)", "[0,0.5)","[0.5,1)"),
#                     labels=c("No Data","Bad","Poor","Acceptable","Good"),
#                     values = c("gray48","#D73026","#FDAD60", "#A5D86A","#199850"),
#                     drop=FALSE)+
#   facet_grid(. ~ paste0("Combined Impact 3")) +
#   theme(
#     axis.title.y = element_blank(),
#     legend.title = element_blank(),
#     legend.position="none")+
#   scale_x_continuous("LT", labels = as.character(1:7), breaks = 1:7)
# 
# p4 = ggplot(data = result_BSS_4, aes(x=LT, y=NUTS, fill=skill2)) + 
#   geom_tile()+ 
#   xlab("LT")+
#   geom_tile(color="white", size=0.0001)+
#   geom_text(aes(label = skill))+
#   scale_fill_manual(breaks=c("[-Inf,-10)","[-10,-0.5)", "[-0.5,0)", "[0,0.5)","[0.5,1)"),
#                     labels=c("No Data","Bad","Poor","Acceptable","Good"),
#                     values = c("gray48","#D73026","#FDAD60", "#A5D86A","#199850"),
#                     drop=FALSE)+
#   facet_grid(. ~ paste0("Combined Impact 3")) +
#   theme(
#     axis.text.y = element_blank(),
#     axis.ticks.y = element_blank(),
#     axis.title.y = element_blank(),
#     legend.title = element_blank())+
#   scale_x_continuous("LT", labels = as.character(1:7), breaks = 1:7)
# 
# 
# 
# w=9
# h=8
# 
# pdf(paste0("F:/Thesis/Figures/4_Validation/Drought_Impact/0_Diff_Cases/Case_4/Skill/BSS.pdf"),width=w,height=h,paper='special')
# 
# grid.arrange(p1,p2,p3,p4, ncol = 3,
#              heights=unit(c(h*0.5,h*0.5), c("in", "in")),
#              widths=unit(c(w*0.42,w*0.42,w*0.13), c("in", "in")),
#              layout_matrix = rbind(c(1, 2, NA),
#                                    c(3, 4, 4)))
# dev.off()
# 
# ############################################################################################
# 
# ## plot skill models
# p1 = ggplot(data = result_ROC_1, aes(x=LT, y=NUTS, fill=skill2)) + 
#   geom_tile()+ 
#   geom_tile(color="white", size=0.0001)+
#   geom_text(aes(label = skill))+
#   scale_fill_manual(breaks=c("[-Inf,0)","[0,0.5)", "[0.5,0.7)", "[0.7,0.8)","[0.8,1)"),
#                     labels=c("No Data","Bad","Poor","Acceptable","Good"),
#                     values = c("gray48","#D73026","#FDAD60", "#A5D86A","#199850"),
#                     drop=FALSE)+
#   facet_grid(. ~ paste0("Combined Impact 1")) +
#   theme(
#     axis.text.x = element_blank(),
#     axis.ticks.x = element_blank(),
#     axis.title.x = element_blank(),
#     axis.title.y = element_blank(),
#     legend.title = element_blank(),
#     legend.position="none")
# 
# p2 = ggplot(data = result_ROC_2, aes(x=LT, y=NUTS, fill=skill2)) + 
#   geom_tile()+ 
#   geom_tile(color="white", size=0.0001)+
#   geom_text(aes(label = skill))+
#   scale_fill_manual(breaks=c("[-Inf,0)","[0,0.5)", "[0.5,0.7)", "[0.7,0.8)","[0.8,1)"),
#                     labels=c("No Data","Bad","Poor","Acceptable","Good"),
#                     values = c("gray48","#D73026","#FDAD60", "#A5D86A","#199850"),
#                     drop=FALSE)+
#   facet_grid(. ~ paste0("Combined Impact 2")) +
#   theme(
#     axis.text.x = element_blank(),
#     axis.ticks.x = element_blank(),
#     axis.text.y = element_blank(),
#     axis.ticks.y = element_blank(),
#     axis.title.x = element_blank(),
#     axis.title.y = element_blank(),
#     legend.title = element_blank(),
#     legend.position="none")
# 
# p3 = ggplot(data = result_ROC_3, aes(x=LT, y=NUTS, fill=skill2)) + 
#   geom_tile()+ 
#   xlab("LT")+
#   geom_tile(color="white", size=0.0001)+
#   geom_text(aes(label = skill))+
#   scale_fill_manual(breaks=c("[-Inf,0)","[0,0.5)", "[0.5,0.7)", "[0.7,0.8)","[0.8,1)"),
#                     labels=c("No Data","Bad","Poor","Acceptable","Good"),
#                     values = c("gray48","#D73026","#FDAD60", "#A5D86A","#199850"),
#                     drop=FALSE)+
#   facet_grid(. ~ paste0("Combined Impact 3")) +
#   theme(
#     axis.title.y = element_blank(),
#     legend.title = element_blank(),
#     legend.position="none")+
#   scale_x_continuous("LT", labels = as.character(1:7), breaks = 1:7)
# 
# p4 = ggplot(data = result_ROC_4, aes(x=LT, y=NUTS, fill=skill2)) + 
#   geom_tile()+ 
#   xlab("LT")+
#   geom_tile(color="white", size=0.0001)+
#   geom_text(aes(label = skill))+
#   scale_fill_manual(breaks=c("[-Inf,0)","[0,0.5)", "[0.5,0.7)", "[0.7,0.8)","[0.8,1)"),
#                     labels=c("No Data","Bad","Poor","Acceptable","Good"),
#                     values = c("gray48","#D73026","#FDAD60", "#A5D86A","#199850"),
#                     drop=FALSE)+
#   facet_grid(. ~ paste0("Combined Impact 4")) +
#   theme(
#     axis.text.y = element_blank(),
#     axis.ticks.y = element_blank(),
#     axis.title.y = element_blank(),
#     legend.title = element_blank())+
#   scale_x_continuous("LT", labels = as.character(1:7), breaks = 1:7)
# 
# w=9
# h=8
# 
# pdf(paste0("F:/Thesis/Figures/4_Validation/Drought_Impact/0_Diff_Cases/Case_4/Skill/ROC.pdf"),width=w,height=h,paper='special')
# 
# grid.arrange(p1,p2,p3,p4, ncol = 3,
#              heights=unit(c(h*0.5,h*0.5), c("in", "in")),
#              widths=unit(c(w*0.42,w*0.42,w*0.13), c("in", "in")),
#              layout_matrix = rbind(c(1, 2, NA),
#                                    c(3, 4, 4)))
# dev.off()
