###########################################################################################################
#### Script: MSc thesis Forecasting Drought Impacts
#### Date: 2019-03
#### Auther: Melati van der Weert
#### Supervisors: Samuel Sutanto, Henny van Lanen, and Niko Wanders
#### Chair group: Hydrology and Quantitative Water Management Group
#### University: Wageningen University & Research, the Netherlands
#### Objective: Calculae skill scores of modeled drought impact 
#### Instructions: Go through the script step by step and execute the R-code (select code and Ctrl-R).
#### If required set the working folder, input folder, and output folder according to your specifications
###########################################################################################################


## set working directory
workdir <- "F:/Thesis/Scripts/Rstudio/4_Validation/Drought_Impacts/Random_Forest/Re-forecasts_Analysis/Case_4/1_Validation_BSS_ROC"
setwd(workdir)

## load functions
source("R/1_ROC.R")
source("R/2_Brier_Score_Skill.R")

## names of the NUTS1 regions in Germany
list_NUTS_Names = c("SL","BW","BV","RP","TH","HE","SX","NW","BE","ST","HB","BB","HH","LS","MP","SH")
## numbers of the NUTS1 regions in Germany
list_NUTS = c("741","743","750","753","775","776","777","791","796","800","810","835","843","858","903","979")
## list of ensambles names
list_ensemble = c("p00","p01","p02","p03","p04","p05","p06","p07","p08","p09","p10","p11","p12","p13","p14")
## list of impact categories
list_category = c("Impact_Combined_1","Impact_Combined_2","Impact_Combined_3","Impact_Combined_4")
## list of dates for wich forecast have been made
list_dates = format(seq(as.Date("2002-01-01"), as.Date("2010-12-01"), "month"), "%Y%m")

## empty array where the results are written in
AUROC_values = array(-999, dim = c(64,7)) 
BSS_values = array(-999, dim = c(64,7)) 
## define row names
rownames(AUROC_values) = c("741-1","741-2","741-3","741-4",
                           "743-1","743-2","743-3","743-4",
                           "750-1","750-2","750-3","750-4",
                           "753-1","753-2","753-3","753-4",
                           "775-1","775-2","775-3","775-4",
                           "776-1","776-2","776-3","776-4",
                           "777-1","777-2","777-3","777-4",
                           "791-1","791-2","791-3","791-4",
                           "796-1","796-2","796-3","796-4",
                           "800-1","800-2","800-3","800-4",
                           "810-1","810-2","810-3","810-4",
                           "835-1","835-2","835-3","835-4",
                           "843-1","843-2","843-3","843-4",
                           "858-1","858-2","858-3","858-4",
                           "903-1","903-2","903-3","903-4",
                           "979-1","979-2","979-3","979-4")
rownames(BSS_values) =  c("741-1","741-2","741-3","741-4",
                          "743-1","743-2","743-3","743-4",
                          "750-1","750-2","750-3","750-4",
                          "753-1","753-2","753-3","753-4",
                          "775-1","775-2","775-3","775-4",
                          "776-1","776-2","776-3","776-4",
                          "777-1","777-2","777-3","777-4",
                          "791-1","791-2","791-3","791-4",
                          "796-1","796-2","796-3","796-4",
                          "800-1","800-2","800-3","800-4",
                          "810-1","810-2","810-3","810-4",
                          "835-1","835-2","835-3","835-4",
                          "843-1","843-2","843-3","843-4",
                          "858-1","858-2","858-3","858-4",
                          "903-1","903-2","903-3","903-4",
                          "979-1","979-2","979-3","979-4")
## define colum names
colnames(AUROC_values) = c(1,2,3,4,5,6,7)
colnames(BSS_values) =  c(1,2,3,4,5,6,7)

#### calculate BSS and ROC
## go trought every NUTS 1 level
for (NUTS in 1:length(list_NUTS)){ print(NUTS)
  ## go trought every impact category
  for (category in 1:length(list_category)){ 
    ## load proxy data wich incloud the proxy drought impact
    proxy = read.table(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Model_Input/Binary/",list_NUTS[NUTS],"/",list_category[category],".csv"),sep = ",",header=TRUE)
    ## create empty array needed to store data
    tmp.array = array(NA, dim = c(108,14,15)) 
    ## go trought every ensamble
    for (ensemble in 1:length(list_ensemble)){
      ## go trought every date
      for(date in 1:length(list_dates)){
        ## check if there is about for this perticalur situation -> if not there was no model built for this situation as the number of ipact reports were limited
        if(isTRUE(class(try(read.table(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Modelled_Drought_Impact/",list_ensemble[ensemble],"/",list_NUTS[NUTS],"/",list_category[category],"/",list_dates[date],".csv"),header = TRUE,sep = ","),TRUE))=="try-error")){
          tmp.array[date,1:7,ensemble] = NA
        } else{
          ## load forecast
          forecast = read.table(paste0("F:/Thesis/Data/3_Random_Forest/Re-forecasts_Analysis/Case_4/Modelled_Drought_Impact/",list_ensemble[ensemble],"/",list_NUTS[NUTS],"/",list_category[category],"/",list_dates[date],".csv"),header = TRUE,sep = ",")
          ## copy to empty array where all forecast for the perticalur NUTS region is merged into
          tmp.array[date,1:7,ensemble] = forecast$x
        }
      }

      
      ## write proxy impact into the empty array
      tmp.array[,8,ensemble] = proxy$Impact[133:240]
      tmp.array[,9,ensemble] = proxy$Impact[134:241]
      tmp.array[,10,ensemble] = proxy$Impact[135:242]
      tmp.array[,11,ensemble] = proxy$Impact[136:243]
      tmp.array[,12,ensemble] = proxy$Impact[137:244]
      tmp.array[,13,ensemble] = proxy$Impact[138:245]
      tmp.array[,14,ensemble] = proxy$Impact[139:246]
    }
   
    #tmp.array[,1:7,][tmp.array[,1:7,] == 1] = 0
    #tmp.array[,1:7,][tmp.array[,1:7,] == 2] = 1

    #tmp.array[,1:7,] = 1-tmp.array[,1:7,]

    ## average the ensemble values
    tmp.array=apply(tmp.array, c(1,2), mean,na.rm=TRUE)
    ## go trough every lead time of the forecast
    for(month in 1:7){
      ## define proxy and forecasted impact for every lead time for the whole case
      impact_proxy = tmp.array[,7+month]
      impact_modelled = tmp.array[,month]
      
      ## calculate BSS and ROC
      BSS=Brier_Score_Skill(proxy$Impact,impact_proxy,impact_modelled)
      AUC=ROC(impact_proxy,impact_modelled)
      print(AUC)
      ## Write the induvidual BSS and ROC values in to a result table
      BSS_values[4*(NUTS-1)+category,month]=BSS
      AUROC_values[4*(NUTS-1)+category,month]=AUC
      
      if(is.na(sum(impact_modelled))){
      }else{
      ## save plot
      jpeg(paste('F:/Thesis/Figures/3_Random_Forest/Re-forecasts_Analysis/Case_4/Modelled_Drought_Impact/',list_NUTS[NUTS],'_Combined_Impact_',category,'-LT',month,'.jpg', sep="")) 
      ## plot predicted timeserie versus observed EDII reports
      plot(seq(as.Date("2002-01-01"), as.Date("2010-12-01"), "months"),impact_proxy,t="l", ylim = c(0, 1),xlab = "Date", ylab = "Impact", col = 'dark gray',main = paste(list_NUTS[NUTS],"Forecasted Combined_Impact_", category,"with LT",month ,sep=" "))
      lines(seq(as.Date("2002-01-01"), as.Date("2010-12-01"), "months"),impact_modelled ,col = 'red')
      dev.off()
      }
    }
  }
}
## write results to CSV file
write.csv(BSS_values,paste0('F:/Thesis/Data/4_Validation/Drought_Impacts/Random_Forest/Re-forecasts_Analysis/Case_4/BSS.csv'))
write.csv(AUROC_values,paste0('F:/Thesis/Data/4_Validation/Drought_Impacts/Random_Forest/Re-forecasts_Analysis/Case_4/ROC.csv'))

