###########################################################################################################
#### Script: MSc thesis Forecasting Drought Impacts
#### Date: 2019-03
#### Auther: Melati van der Weert
#### Supervisors: Samuel Sutanto, Henny van Lanen, and Niko Wanders
#### Chair group: Hydrology and Quantitative Water Management Group
#### University: Wageningen University & Research, the Netherlands
#### Objective: Plot skill scores of forecasted drought impacts
#### Instructions: Go through the script step by step and execute the R-code (select code and Ctrl-R).
#### If required set the working folder, input folder, and output folder according to your specifications
###########################################################################################################


## load required packages
library(readr)
library(lattice)
library(ggplot2)
library(RColorBrewer)
library(grid)
library(gridExtra)
library("scales")


## number and names of the NUTS1 regions in Germany
list_NUTS = c("741","743","750","753","775","776","777","791","796","800","810","835","843","858","903","979")

## load the skill scores
BSS = read.table("F:/Thesis/Data/4_Validation/Drought_Impacts/Random_Forest/Re-forecasts_Analysis/Case_4/BSS.csv",header = TRUE,sep = ",")
ROC = read.table("F:/Thesis/Data/4_Validation/Drought_Impacts/Random_Forest/Re-forecasts_Analysis/Case_4/ROC.csv",header = TRUE,sep = ",")


## go trough th combined impact categories
for(category in 1:4){

  ## create empty table for results
  data_BSS <- data.frame(matrix(ncol = 3, nrow = 112))
  z <- c("NUTS","LT","skill")
  colnames(data_BSS) <- z
  
  ## create empty table for results
  data_ROC <- data.frame(matrix(ncol = 3, nrow = 112))
  z <- c("NUTS","LT","skill")
  colnames(data_ROC) <- z
  
  ## go trough every NUTS region
  for (NUTS in 1:length(list_NUTS)){
    
    ## order the skill scores in the desired way
    data_BSS$NUTS[((NUTS-1)*7+1):(NUTS*7)]=list_NUTS[NUTS]
    data_BSS$LT[((NUTS-1)*7+1):(NUTS*7)]=1:7
    data_BSS$skill[((NUTS-1)*7+1):(NUTS*7)]=as.numeric(round(BSS[(NUTS-1)*4+category,2:8], digits = 2))
    
    ## order the skill scores in the desired way
    data_ROC$NUTS[((NUTS-1)*7+1):(NUTS*7)]=list_NUTS[NUTS]
    data_ROC$LT[((NUTS-1)*7+1):(NUTS*7)]=1:7
    data_ROC$skill[((NUTS-1)*7+1):(NUTS*7)]=as.numeric(round(ROC[(NUTS-1)*4+category,2:8], digits = 2))
  }
  
  ## order the skill scores in the desired way
  data_BSS$skill1=data_BSS$skill
  data_BSS$skill1[is.na(data_BSS$skill1)]=-999
  data_BSS$skill2 <- cut(data_BSS$skill1,breaks = c(-Inf,-10,-0.5,0,0.5,1),right = FALSE)
  
  ## order the skill scores in the desired way
  data_ROC$skill1=data_ROC$skill
  data_ROC$skill1[is.na(data_ROC$skill1)]=-999
  data_ROC$skill2 <- cut(data_ROC$skill1,breaks = c(-Inf,0,0.5,0.7,0.8,1),right = FALSE)
  
  #### create BSS images
  ## output location
  jpeg(paste0("F:/Thesis/Figures/4_Validation/Drought_Impacts/Skill_Score_Forecasted_Drought_Impacts/Random_Forest/Case_4/BSS/Combined_Impact_",category,".jpg"))
  
  ## plot images
  plot_BSS = ggplot(data = data_BSS, aes(x=LT, y=NUTS, fill=skill2)) + 
    geom_tile()+ 
    geom_tile(color="white", size=0.0001)+
    geom_text(aes(label = skill))+
    scale_fill_manual(breaks=c("[-Inf,-10)","[-10,-0.5)", "[-0.5,0)", "[0,0.5)","[0.5,1)"),
                      labels=c("No Data","Bad","Poor","Acceptable","Good"),
                      values = c("gray48","#D7191C","#FDAE61","#ABDDA4", "#2B83BA"),
                      drop=FALSE)+
    theme(legend.title = element_blank())
  
  plot(plot_BSS)
  
  ## close device
  dev.off()
  
  
  #### create ROC images
  ## output location
  jpeg(paste0("F:/Thesis/Figures/4_Validation/Drought_Impacts/Skill_Score_Forecasted_Drought_Impacts/Random_Forest/Case_4/ROC/Combined_Impact_",category,".jpg"))
  
  ## plot images
  plot_ROC = ggplot(data = data_ROC, aes(x=LT, y=NUTS, fill=skill2)) + 
    geom_tile()+ 
    geom_tile(color="white", size=0.0001)+
    geom_text(aes(label = skill))+
    scale_fill_manual(breaks=c("[-Inf,0)","[0,0.5)", "[0.5,0.7)", "[0.7,0.8)","[0.8,1)"),
                      labels=c("No Data","Bad","Poor","Acceptable","Good"),
                      values = c("gray48","#D7191C","#FDAE61","#ABDDA4", "#2B83BA"),
                      drop=FALSE)+
    theme(legend.title = element_blank()) 
  
  plot(plot_ROC)
  
  ## close device
  dev.off()
}


