###########################################################################################################
#### Script: MSc thesis Forecasting Drought Impacts
#### Date: 2019-03
#### Auther: Melati van der Weert
#### Supervisors: Samuel Sutanto, Henny van Lanen, and Niko Wanders
#### Chair group: Hydrology and Quantitative Water Management Group
#### University: Wageningen University & Research, the Netherlands
#### Objective: Plot skill scores of forecasted drought impacts for report image
#### Instructions: Go through the script step by step and execute the R-code (select code and Ctrl-R).
#### If required set the working folder, input folder, and output folder according to your specifications
###########################################################################################################


## load required packages
library(readr)
library(lattice)
library(ggplot2)
library(RColorBrewer)
library(grid)
library(gridExtra)
library("scales")


## number and names of the NUTS1 regions in Germany
list_NUTS = c("741","743","750","753","775","776","777","791","796","800","810","835","843","858","903","979")
list_NUTS1 = c("SL","BW","BV","RP","TH","HE","SX","NW","BE","ST","HB","BB","HH","LS","MP","SH")

## list of skill scores
list_criteria = c("ROC")

## make empty table for results of ranked predictors
data = data.frame("NUTS"= character(), "LT"= integer(),"category"= integer(), "skill"= integer(), "criteria"= character())

## read the skill scores
BSS = read.table("F:/Thesis/Data/4_Validation/Drought_Impacts/Random_Forest/Re-forecasts_Analysis/Case_4/BSS.csv",header = TRUE,sep = ",")
ROC = read.table("F:/Thesis/Data/4_Validation/Drought_Impacts/Random_Forest/Re-forecasts_Analysis/Case_4/ROC.csv",header = TRUE,sep = ",")

## go trough the skill scores
for(criteria in list_criteria){
  ## go trough every NUTS region
  for (NUTS in 1:length(list_NUTS)){
    ## gotrough the lead times
    for(LT in 1:7){
      ## go trough the impact categories
      for(category in 1:4){
        ## create row with data  
        newRow <- data.frame("NUTS"= list_NUTS1[NUTS], "LT"= LT, "category"= category, "skill"= eval(parse(text=paste0("as.numeric(round(",criteria,"[(",NUTS,"-1)*4+",category,",",LT,"+1], digits = 1))"))), "criteria"= criteria)
        ## ad new row to excisting dataframe
        data=rbind(data,newRow)
      }
    }  
  }
}
  
## make changes to dataframe with all results
data$skill1=data$skill
data$skill1[is.na(data$skill1)]=-999
data$skill2=data$skill1
data$skill2[1:448] <- cut(data$skill1[1:448],breaks = c(-Inf,0,0.5,0.7,0.8,1.1),right = FALSE)
data$skill2[1:448] [data$skill2[1:448]  == "[-Inf,0)"] <- "No Data"
data$skill2[1:448] [data$skill2[1:448]  == "[0,0.5)"] <- "Bad"
data$skill2[1:448] [data$skill2[1:448]  == "[0.5,0.7)"] <- "Poor"
data$skill2[1:448] [data$skill2[1:448]  == "[0.7,0.8)"] <- "Acceptable"
data$skill2[1:448] [data$skill2[1:448]  == "[0.8,1.1)"] <- "Good"

## location to save figure
pdf(paste('F:/Thesis/Figures/4_Validation/Drought_Impacts/Skill_Score_Forecasted_Drought_Impacts/Random_Forest/Case_4/ROC_Skill_Case_4_Merged.pdf', sep=""),width=7,height=3.9,paper='special')

## create figure
p = ggplot(data, aes(x=LT, y=NUTS, fill=skill2)) + 
  geom_tile()+ 
  scale_y_discrete(expand = c(0, 0))+
  xlab("LT [months]")+
  ylab("NUTS-1 Region")+
  scale_x_continuous(expand = c(0, 0),breaks = c(1,2,3,4,5,6,7))+
  geom_tile(color="white", size=0.0001)+
  geom_text(aes(label = skill), size=2.2)+
  facet_grid(~category,   labeller = labeller(
    category = c(`1` = "A. Agriculture and\n Livestock Farming\n+ Forestry", `2` = "B. Energy & Industry\n+ Transportation\n+ Public Water Supply",`3` = "C. Water Quality\n+ Freshwater Ecosystem\n + Terrestrial Ecosystem", `4` = "D. Wildfire + Air Quality\n + Human Health\n & Public Safety")))+
  scale_fill_manual(labels=c(" No Data  "," Fail  "," Poor  "," Fair  "," Good  "),
                    values = c("gray48","#D73026","#FDAD60", "#A5D86A","#199850"),
                    drop=FALSE)+
  theme(legend.title = element_blank(),
        strip.text = element_text(size = 8),
        axis.title = element_text(size = 9),
        axis.text=element_text(size = 7),
        legend.text=element_text(size = 8),
        legend.key.size = unit(0.75,"line"),
        legend.position="bottom")

## plot figure
plot(p)

## close window
dev.off()    
    
